## ===========================================================================
##   FCSmetadata class
## ---------------------------------------------------------------------------
## An object describing the annotation on each data
## 
## ---------------------------------------------------------------------------

## Contains critical metadata at top level, rest subseted.
setClass("FCSmetadata",
         representation(mode="character",
                        size="numeric",
                        nparam="numeric",
                        shortnames="vector",
                        longnames="vector",
                        paramranges="vector",
                        filename="character",
                        objectname="character",
                        original="logical",
                        fcsinfo="list"), ## holds misc params from fcs file
         prototype=list(mode="",
           size=0,
           nparam=0,
           shortnames=vector(mode="character"),
           longnames=vector(mode="character"),
           paramranges=vector(mode="numeric"),
           filename="None",
           objectname="None",
           original=TRUE,
           fcsinfo=list()))

## ===========================================================================
## FCS class
## ---------------------------------------------------------------------------
## A container for flow cytometry measurements with slots exprs, description
## and well. Exprs contains measurement values, description contains 
## information from file headers of FCS file and well contains well position
## on microtiter plate from experiment. Gate contains an object of class
## gateSet, which may be assessed for subsequent operations, e.g.plotting.
## ---------------------------------------------------------------------------

setClass("FCS",
         representation(data="matrix", # flour data
                        metadata="FCSmetadata"),
         prototype=list(data=matrix(),
           metadata=new("FCSmetadata")))



## ===========================================================================
##   FCSsummary class
## ---------------------------------------------------------------------------
## An object summaryzing an FCS object
## 
## ---------------------------------------------------------------------------

setClass("FCSsummary",
         representation(num.cells="numeric",
                        num.param="numeric",
                        univariate.stat="matrix",
                        metadata.info="list"),
         prototype=list(num.cells=0,
           num.param=0, univariate.stat=matrix(),
           metadata.info=list()))


##----------------------------------------------------------------------------
