ContourScatterPlot <-  function(xvar, ## X1
                                yvar, ## X2
                                status=NULL, ## status of the observation 0,1
                                type.CSP=c("count.diff", "p.hat", "p.hat.norm", "z.stat"),
                                xlab=NULL, ylab=NULL,
                                main=NULL,
                                x.grid = round(seq(range(xvar)[1],
                                  ceiling(diff(range(xvar))/25)*25+range(xvar)[1],
                                  by=25),0),
                                y.grid =round(seq(range(yvar)[1],
                                  ceiling(diff(range(yvar))/25)*25+range(yvar)[1],
                                  by=25),0),
                                lattice=FALSE,
                                hexbin.plotted=FALSE,
                                hexbin.style=c("colorscale",
                                  "lattice", "centroids",
                                  "nested.lattice", "nested.centroids"),
                                n.hexbins=100,
                                numlev=5,
                                xaxt="s",
                                yaxt="s",
                                image.col=heat.colors(10),...) {
  
    
  ## Objective:

  ## To make a bivariate image and a superimposed contour plot
  ## of xvar versus yvar
  ##
  ## Note: This function calls make.grid for the counts in the grid which
  ## make up the image plot.

  ## Input variables:

  ## Name         Description

  ## xvar       numerical vector of the x-variable
  ## yvar       numerical vector of the y-variable
  ## xlab       character string of the x-variable name
  ## ylab       character string of the y-variable name
  ## main       character string of title of the plot
  ## x.grid     numerical vector of the x-axis breaks for the image plot
  ## y.grid     numerical vector of the y-axis breaks for the image plot
  ## image.col  color type for the image plot; default= heat.colors(10)
  ## numlev     number of levels for the contour plot; default value=50

  ## Output Results:
  hexbin.style <- match.arg(hexbin.style)
  
  lib.there <- require(hexbin)
  if (lib.there ==TRUE & hexbin.plotted==TRUE){
    bin <- hexbin(xvar, yvar, xbins=n.hexbins)
    
    ##  NOTE: can only plot one hexbin plot on one page
    ##  can overlay vertical lines and points on the hexbin plots though
    plot(bin, xlab=xlab, ylab=ylab, style=hexbin.style,main= main,...)

    # we can bin the ycm and the xcm after sorting, and we have the cnt... but is this right?
    # sort(round(bin$ycm, 2))
    ##title(main = main, font.main = 4)
  }
  else {
    if(is.null(status)){
      grid.tally <- make.grid(xvar, yvar, x.grid=x.grid, y.grid=y.grid)
    }
    else{
      type.CSP <- match.arg(type.CSP)
      grid.tally <- make.density(xvar, yvar, status=status, x.grid=x.grid, y.grid=y.grid, type.CSP=type.CSP)
    }
    
   ## if (plot.legend.CSP==TRUE){
   ##     ch.col <- match.arg(ch.col)
   ##     ##print(ch.col )
   ##     legend.CSP(grid.tally$z, length(image.col), ch.col=ch.col, main=paste(type.CSP, "in grid cells"))
   ##
}
  
  if (lattice==FALSE & hexbin.plotted==FALSE){
    
      image(x.grid, y.grid, grid.tally$z, axes=FALSE,
            col=image.col, xlab=xlab, ylab=ylab)
      
      contour(x.grid[1:(length(x.grid)-1)],
              y.grid[1:(length(y.grid)-1)],
              grid.tally$z, nlevels=numlev, add=TRUE, ...)
      
      if (xaxt=="s"){
          axis(1, at = x.grid)
      }
      if (yaxt=="s"){
          axis(2, at = y.grid)
      }
      box()
      title(main = main, font.main = 4)
  }
 if(lattice==TRUE){
      z <- matrix(unlist(grid.tally$z),nrow=nrow(grid.tally$z),byrow=FALSE)
      
      colnames(z) <- x.grid[1:(length(x.grid)-1)]
      rownames(z) <- y.grid[1:(length(y.grid)-1)]
      
      colori <- colorRampPalette(image.col, space = "Lab")
      
      levelplot(z,
                panel="panel.levelplot",
                pretty=TRUE,
                contour=TRUE,labels=TRUE,
                cuts=numlev,
                col.regions=colori(40),
                colorkey=list(col=colori(40)),
                axis = list(side=c("left","bottom")),
                scales = list(tck = c(1, 0), x=list(alternating=1, rot = 90),y=list(alternating=1)),
                main =main,xlab=xlab,ylab=ylab)
      
      
  }
}
