ImageParCoord <- function(x, ## x is a matrix
                          num.bins=10,
                          range.var=range(x),
                          break10 = NULL,
                          joint=FALSE,
                          title="",
                          use.shortnames=FALSE,
                          color.image=gray((25:5/25)[-c(1,2,3, 4, 5, 6)]),
                          xwidth.scale=5,
                          ntrans=1,
                          legend.plotted=TRUE,
                          legend.shrink = 0.9,
                          hist.plotted=FALSE,
                          image.plotted=TRUE,
                          para.plotted=FALSE,
                          lines.plotted=TRUE,
                          lwd.vec=1:7,
                          lty.vec=rep(1,7),
                          col.vec=7:1,
                          range.image=c(0,dim(x)[1]),
                          horizontal.legend = TRUE,
                          offset.legend=0.03,
                          nlevel.legend=length(color.image),
                          xlab.image="",
                          ylab.image="Bins",
                          MY.DEBUG=TRUE,...){

 
    
    break10 <- defineBreak(x,num.bins, range.var, break10=break10,MY.DEBUG= MY.DEBUG)
    max.lwd <- max(lwd.vec)
    variable.names <- colnames(x)
    nvar <- dim(x)[2]

    if (nvar < 2){
        stop("nvar should be equal to or greater than 2.")
    }
    
    
    imageBlockinfo <- imageBlock(x=x, num.bins=num.bins, ntrans=ntrans, xwidth.scale=xwidth.scale, hist.plotted=hist.plotted, breaks=break10)
    image.block <- imageBlockinfo[[1]]
    coords <- imageBlockinfo[[2]]
    V1.hist <- imageBlockinfo[[3]]

    varlabpos <- vector()
    for (i in 1:nvar){
        curpos <- ifelse(i==1, (ntrans*xwidth.scale)/2, (ntrans*xwidth.scale)/2 + 2*(i-1)*ntrans*xwidth.scale )
        varlabpos <- c(varlabpos, curpos)
    }

    if (image.plotted==TRUE){
        ## display the image plot
        display.imagepl(image.block,V1.hist,
                        varlabpos,
                        variable.names,
                        zlim= range.image,
                        col= color.image,
                        horizontal = horizontal.legend,
                        legend.shrink = legend.shrink,
                        offset= offset.legend,
                        nlevel= nlevel.legend,
                        xlab= xlab.image,
                        ylab= ylab.image,
                        main= title)
    } 


    if (joint==FALSE){
        info <- list()
        lines.ls <- list()
        for (varcol in 2:nvar){
            
            first <- varcol-1
            second <- varcol
            
            V1.coord <- coords[,first]
            V2.coord <- coords[,second]
            tab<-table(V1.coord, V2.coord)
            
            
            rows <- sort(unique(V1.coord))
            cols <- sort(unique(V2.coord))
            
            twocoord <- NULL
            for (c in 1:length(cols)){
                for (r in 1: length(rows)){
                    twocoord <- rbind(twocoord, c(rows[r], cols[c]))
                }
            }
            
            colnames(twocoord) <- c(paste("V", first, ".bin", sep=""), paste("V", second, ".bin", sep=""))
            
            pos <- which(tab!=0)
            num.lines <- tab[pos]       
            coords.nozero <- twocoord[pos,]
            
            info[[varcol-1]] <- cbind(coords.nozero, num.lines)
            rownames(info[[varcol-1]]) <- NULL
            lines.ls[[varcol-1]]<- num.lines
        }
    }

    if (joint==TRUE){
        
        ## sort the last element of the list
        sort.pos <- sort(coords[[nvar]], decreasing=FALSE, index.return=TRUE)$ix
        coords <- sortL(coords, sort.pos)
        tab <- table(coords)
        coords.mat <- matrix(unlist(coords), ncol=nvar)
        var.pat <- unique(coords.mat)
        
        dim.name <- labels(tab)
        num.types <- lapply(dim.name, function(w){length(w)})
        ## get the position of the row in the
        ## corresponding element in the list dim.name
                
        dimensions <- t(apply(var.pat, 1, function(row){
            pos <- getPos(row, dim.name)
            
        }))
        
        ## convert the dimensions into the real positions in a vector
        ## please note that R converts lists and matrices into vectors
        ## by column, or else this following procedure will be wrong!
        real.pos <- NULL
        for (row in 1:(dim(dimensions)[1])){
            value <- dimensions[row,1]
            mult <- 1
            for (i in 1:(length(num.types)-1)){
                mult <- mult*num.types[[i]]
                value <- value + (dimensions[row,i+1]-1)*mult
            }
            real.pos <- c(real.pos, value)
        }
        
        ## transform the table into a vector: R does this
        ## by column (not by row...) using as.vector
        
        tab.vec <- as.vector(tab)
        num.lines <- tab.vec[real.pos]
        
        line.info<- cbind(var.pat, num.lines)
        
        
        info <- list()
        lines.ls <- list()
        first.var <- line.info[,1]
        
        for (pair in 2:(dim(var.pat)[2])){
            second.var <- line.info[,pair]
            info[[pair-1]] <- cbind(first.var, second.var, num.lines)
            lines.ls[[pair-1]] <- num.lines
            first.var <- second.var
        }
    }
    ## get the max number of lines
    max.size <- max(num.lines)
    min.size <- min(num.lines)

    
    plotLine(max.size, min.size, range.var = range.var, info=info, varlabpos, lwd.vec, lty.vec, col.vec,
             lines.plotted= lines.plotted, legend.plotted = legend.plotted, bg=color.image[1],
             lines.ls, image.plotted=image.plotted)


    
    ## real parallel coordinates
    if(para.plotted==TRUE){
        parallelCoordinates(x,
                             varlabpos=varlabpos, variable.names=variable.names,
                             at.y=round(V1.hist$breaks, 1)[-1], superimpose=FALSE)
        
        box()
        title(main = title, font.main = 4)
        abline(v=varlabpos)
    }
    
    if (is.null(info)==TRUE){
        return(list(image.block=image.block, breaks=break10))
    } else{
        return(list(image.block=image.block, line.info=info, breaks=break10))
    }
}
 

############################################################################################################################################

defineBreak <- function(x,num.bins, range.var, break10=NULL, MY.DEBUG=TRUE){

    if (is.null(break10)){
        break10 <- seq(range.var[1]-1, range.var[2], by=(range.var[2]/num.bins)) 
    }
   ## num.bins is the number of bins for the image plot
   if(num.bins!=(length(break10)-1)){
       if (MY.DEBUG){
           cat("\n\n", "Number of bins, num.bins, has been changed from", num.bins, "to",
               length(break10)-1, "\n\n")
       }
       num.bins <- length(break10)-1
   }
   
   if( break10[length(break10)]<range.var[2] ){
       if (MY.DEBUG){
           cat("\n\n", "The following breaks for the binning:","\n")
           print(break10)
           cat("should be inclusive of the range:", "\n")
           print(range.var)
       }
       seq1 <- seq(range.var[1]-1, range.var[2], by=range.var[2]/num.bins)
       break10 <- c(seq1[-length(seq1)], range.var[2])
       if (MY.DEBUG){
           cat("\n\n", "Thus, the breaks, break10, has been changed to:", "\n")
       }
   }
    return(break10)
   
}

imageBlock <- function(x, num.bins, ntrans, xwidth.scale, hist.plotted=hist.plotted, breaks){
  
     image.block <- coords<- NULL
     nvar <- dim(x)[2]
     variable.names <- colnames(x)
     ## check that ntrans is bigger than 1
     if (ntrans <1) {
         stop("ntrans should be greater than or equal to 1")
     }
  
     trans.ct <- rep(0, num.bins*xwidth.scale) ## initialize the transition count to zeros

     V1 <- x[, 1]
     if(hist.plotted==TRUE){
         V1.hist <- hist(V1, freq=FALSE, 
                         breaks=breaks, main= paste("Histogram of", variable.names[1], sep=" "),  xlab=variable.names[1], plot=hist.plotted)
     }
     else{
         V1.hist <- hist(V1, breaks=breaks, plot= hist.plotted)
     }
     
     V1.ct <- V1.hist$counts
     V1.block<-matrix(rep(V1.ct, ntrans*xwidth.scale), ncol=ntrans*xwidth.scale)
     xcoord <- 1:(2+ntrans)
     V1.xpos <- 1
     V1.breaks <- V1.hist$breaks[-1]

     for (second in 2:nvar){
         
       V2 <- x[, second]
       ## histograms with 10 bins
       ##V2.hist <- hist(V2,  breaks=breaks, main=paste("Histogram of", variable.names[second], sep=" "),
       ##                xlab=variable.names[second], plot=FALSE)
       V2.hist <- hist(V2, breaks=breaks, plot=FALSE)
       V2.ct <- V2.hist$counts
    
       ## make the variable image blocks
       V2.block<-matrix(rep(V2.ct, ntrans*xwidth.scale), ncol=ntrans*xwidth.scale)

       ## for each cell/row observation make a slope line formula and
       ## predict the vertical bins (y-coordinate) that the observations
       ## lie depending on the position of the horizontal bin (x-coordinate)
       
       ## make x-coordinates
       ## only does 2 variables right now
       V2.xpos <- length(xcoord)
       xdiff <- V2.xpos-V1.xpos
  
       ## predict the y-coordinates from the x-coordinates
       ycoord.trans <- apply(cbind(V1, V2), 1, function(row){
           ydiff <- row[2]-row[1]
           slope <- ydiff/xdiff
           ypred <- sapply(xcoord[-c(V1.xpos, V2.xpos)], function(x){
               return(slope*(x-V1.xpos)+row[1])
           })
           return(round(ypred,0))
       })
    
       ycoord.trans <- matrix(unlist(ycoord.trans), ncol=length(xcoord[-c(V1.xpos, V2.xpos)]), byrow=TRUE)
       ## get the trans hist for each trans
       trans.block <- NULL
       for (i in 1:ntrans){
           if (hist.plotted==TRUE){
               trans.hist <- hist(ycoord.trans[,i], main=paste("Histogram of trans", i, sep=""),
                                  xlab=variable.names[2], breaks=breaks, plot=hist.plotted, freq=FALSE)
           }
           else { trans.hist <- hist(ycoord.trans[,i], breaks=breaks, plot=hist.plotted)}
           trans.block <- cbind(trans.block, matrix(rep(trans.hist$counts, xwidth.scale), ncol=xwidth.scale))
       }
       
       if (hist.plotted==TRUE){
           V2.hist <- hist(V2, main=paste("Histogram of", variable.names[second], sep=" "),
                           xlab=variable.names[second], breaks = breaks, plot=TRUE, freq=FALSE)
           
       }
       ## make the total image block
       image.block <- cbind(image.block, V1.block, trans.block)

       V2.breaks <- V2.hist$breaks[-1]
       ## to center the coordinates in the blocks
       V1.coord <- getcoord(V1, V1.breaks) +0.5
       V2.coord <- getcoord(V2, V2.breaks) + 0.5
       coords <- cbind(coords, V1.coord)
       V1 <- V2
       
   }
     image.block <- cbind(image.block, V2.block)
     coords <- cbind(coords, V2.coord)
     
     return(list(image.block, coords,V1.hist))
 }


getcoord <- function(V, V.breaks){
    V.coord <- NULL
    for (i in 1:(length(V))) {
        ## j is the bin number for each element of V
        j <- 1
        while ((j < length(V.breaks)) & (V[i] >= V.breaks[j])){
            j <- j+1
        }
        
        V.coord <-c(V.coord, j)
        
    }
    return(V.coord)
}


 
display.imagepl <- function(image.block, V1.hist,
                            varlabpos,
                            variable.names,
                            zlim,
                            col,
                            horizontal,
                            legend.shrink,
                            offset,
                            nlevel,
                            xlab,
                            ylab,
                            main,...){

    ## coordinates of the image block
    col.coord<-1:(dim(image.block)[2]+1)
    row.coord <- 1:(dim(image.block)[1]+1)

    image(col.coord, row.coord, t(image.block), zlim=zlim, col=col, axes=FALSE,
          xlab=xlab, ylab=ylab, ...)

    ## lib.there <- require(fields)
    ##if (lib.there==FALSE){
    ##    warning("The function image.plot in Library fields is needed for the image parallel coordinates plot to have a color legend.")
    ##} else {
        image.plot(col.coord, row.coord, t(image.block), zlim =zlim, legend.only = TRUE, legend.shrink = legend.shrink,
                   horizontal = horizontal, col=col, offset=offset, nlevel=nlevel, axes=FALSE,
                   xlab=xlab, ylab=ylab, ...)
    ##}
    
    axis(2, at=1:length(V1.hist$breaks), lab=round(V1.hist$breaks, 1))
    axis(1, at=varlabpos, lab=variable.names)
    box()
    title(main, font.main = 4)
    abline(v=varlabpos)
}


plotLine <- function(max.size, min.size, range.var, varlabpos, info,
                     lwd.vec, lty.vec, col.vec, lines.plotted,
                     legend.plotted, bg, lines.ls, image.plotted=lines.plotted){

    scaled.size.ls <- NULL
    max.lwd <- max(lwd.vec)
    
    ## plotting of the lines from the last variable to the first
    for(i in length(info):1){
        ## ordering to plot the large num lines first
        kk <- info[[i]]
        rownames(kk) <- NULL
        order.kk <- sort(kk[,3], decreasing=FALSE, index.return=TRUE)$ix
        kk <- kk[order.kk,]
        
        ## actual plotting of the lines
        scaled.size.el <- apply(kk, 1, function(y){
            scaled.size <- (max.lwd-1)*((y[3]-min.size)/(max.size-min.size))+1
            lwd.current <- round(scaled.size,0)
            pos <- which(lwd.vec==lwd.current)
            
            if (lines.plotted==TRUE) {
                if (image.plotted ==TRUE) {
                    lines(varlabpos[c(i,i+1)], c(y[1], y[2]), lwd=lwd.current,
                          col=col.vec[pos], lty=lty.vec[pos])
                } else {
                    warning("'lines.plotted'=TRUE, but lines could not be plotted because 'image.plotted'=FALSE")
                }
            }
            return(round(scaled.size, 0))
        })
        ##go back to the original order
        order.orig <- sort(order.kk, decreasing=FALSE, index.return=TRUE)$ix
        scaled.size.ls <- c(scaled.size.el[order.orig], scaled.size.ls)
    }
    lines.ls <- unlist(lines.ls)
    names(lines.ls) <- NULL
    
    cts.ls <- cts.ls2 <- NULL
    for (j in 1:max.lwd){
        if (is.element(j, scaled.size.ls)==TRUE){
            cts.max <-max(lines.ls[scaled.size.ls==j])
            cts.min <- min(lines.ls[scaled.size.ls==j])
            cts.ls <- c(cts.ls, cts.min)
            cts.ls2 <- c(cts.ls2, cts.max)
        } else {
            cts.ls <- c(cts.ls, "--")
            cts.ls2 <- c(cts.ls2, "--")
        }
    }
    if (legend.plotted) {
        plot(1:range.var[2],1:range.var[2], xlab="", ylab="", type="n", main="Key for counts signified by the line", xaxt="n", yaxt="n" )
        legend(range.var[1], range.var[2], paste(cts.ls, "<= Counts <=", cts.ls2), lwd=lwd.vec, col=col.vec, lty=lty.vec, bg=bg)
    }    
}

    

sortL <- function(coords, sort.pos){
    lapply(coords, function(w){w[sort.pos]})
}

getPos <- function(row, dim.name){
    info <- cbind(row, 1:length(row))
    pos <- apply(info, 1, function(w){
        which(w[1]==as.numeric(dim.name[[w[2]]]))
    })
    return(unlist(pos))
    
}


########## Joint ImageParCoord ######
JointImageParCoord <- function(x,
                               num.bins=10,
                               range.var=range(x),
                               break10=NULL,
                               title="",
                               use.shortnames=FALSE,
                               color.image=gray((25:5/25)[-c(1,2,3, 4, 5, 6)]),
                                        #rainbow(16, start=.4, end=.1),#
                               xwidth.scale=5,
                               ntrans=1,
                               legend.plotted = TRUE,
                               legend.shrink = 0.9,
                               hist.plotted = FALSE,
                               image.plotted = TRUE,
                               para.plotted = FALSE,
                               lines.plotted = TRUE,
                               lwd.vec=1:7,
                               lty.vec=rep(1,7),
                               col.vec=7:1,
                               range.image=c(0, dim(x)[1]),
                               horizontal.legend = TRUE,
                               offset.legend=0.03,
                               nlevel.legend=length(color.image),
                               xlab.image="",
                               ylab.image="Bins",
                               MY.DEBUG=TRUE,... ){

    warning("The function is deprecated.")
    
    ## x   a FCS object; data has columns as the variables and rows as
    ##            the cells
    ## var.pos    a vector of the column positions of the variables of interest
    ## num.cells  the vector consisting of the row positions of the cells to be
    ##            analyzed
    ## num.bins   the number of bins to determine how well-defined/sharp the
    ##            columns of the image plot are
    ## xwidth.scale  x-width of the transition columns 
    ## ntrans     the number of transition columns in the image parallel
    ##            coordinates plot
    ##            (only works for an odd number of transition columns currently)
    ## hist.plotted   boolean; if TRUE then the histogram plots of the variables
    ##             and the transitions are made; otherwise no plot; default is
    ##             FALSE
    ## image.plotted  boolean; if TRUE then the image parallel coordinates plot
    ##             is made; otherwise no plot; default is TRUE
    ## max.lwd     maximum line width size

    ## output is to create a histograms of the column variable of interest and an
    ## image parallel coordinates plot with lines of varying thickness depending
    ## on the number of cells in the certain column image block of the image
    ## parallel coordinates plot
    
    
    
    
    ## What to do?
    
    
    ## 4. There is a rounding error
    ## 5.  change the default color.image to gray scale (look at the example below)
    
    ## 6.  make help file detailing what the scale of the lines is
    ##     and how the graph was made (later)
    ## 7.  lines (should there be an lty?  different colors than the ones there?
    ## 8. isolate number of lines to draw the small lines first and then the large ones
    
    
    
    ## color.image <- match.arg(color.image)
    
    ## num.bins is the number of bins for the image plot
    range.var <- range(x)
    if (is.null(break10)){
        
        break10 <- seq(range.var[1]-1, range.var[2], by=(range.var[2]/num.bins))
    }
    
    if(num.bins!=(length(break10)-1)){
        if (MY.DEBUG) {
            cat("\n\n", "Number of bins, num.bin, has been changed from", num.bins, "to", length(break10)-1, "\n\n")
        }
        num.bins <- length(break10)-1
    }
    
    if( break10[length(break10)]<range.var[2] ){
        if (MY.DEBUG){
            cat("\n\n", "The following breaks for the binning:","\n")
            print(break10)
            cat("should be inclusive of the range:", "\n")
            print(range.var)
        }
        seq1 <- seq(range.var[1]-1, range.var[2], by=range.var[2]/num.bins)
        break10 <- c(seq1[-length(seq1)], range.var[2])
        if (MY.DEBUG) {
            cat("\n\n", "Thus, the breaks, break10, has been changed to:", "\n")
            print(break10)
        }
        
    }
    
    
    max.lwd <- max(lwd.vec)
    
    
    ## if(use.shortnames==TRUE){
    ##    short.lab <- paste("$P", var.pos, "N", sep="")
    ##    variable.names <- sapply(short.lab, function(x){EMI(x, "",  metavar=x)$slot})
    ##  } else{
    variable.names <- colnames(x)
    ##  }
    
    
    ## makes an image parallel coordinates plot for
    
    nvar <- dim(x)[2]
    
    if (nvar < 2){
        stop("nvar should be equal to or greater than 2.")
    }
    
  ###########################################################
  ##### Step 1: Getting the image block for each pair #######
  #####   of coordinates in a for loop                #######
  ###########################################################
  
    image.block <- NULL
    coords <- list()
    V1 <- x[,1]
    V1.hist <- hist(V1, main=paste("Histogram of", variable.names[1], sep=" "),
                    xlab=variable.names[1], breaks=break10, plot=hist.plotted, freq=TRUE)
    for (varcol in 2:nvar){
        
        second <- varcol
        
        
        
        V2 <- x[,second]
        ## histograms with 10 bins
        
        V2.hist <- hist(V2, main=paste("Histogram of", variable.names[second], sep=" "),
                        xlab=variable.names[second], breaks=break10, plot=FALSE)
        
        V1.ct <- V1.hist$counts
        V2.ct <- V2.hist$counts
        
        
        
        ## initialize the transition count to zeros
        trans.ct <- rep(0, num.bins*xwidth.scale)
        
        
        ## make the variable image blocks
        V1.block<-matrix(rep(V1.ct, ntrans*xwidth.scale), ncol=ntrans*xwidth.scale)
        V2.block<-matrix(rep(V2.ct, ntrans*xwidth.scale), ncol=ntrans*xwidth.scale)
        
        
        ## check that ntrans is bigger than 1
        if (ntrans <1) {
            stop("ntrans should be greater than or equal to 1")
        }
        
        ## for each cell/row observation make a slope line formula and
        ## predict the vertical bins (y-coordinate) that the observations
        ## lie depending on the position of the horizontal bin (x-coordinate)
        
        ## make x-coordinates
        
        ## only does 2 variables right now
        xcoord <- 1:(2+ntrans)
        V1.xpos <- 1
        V2.xpos <- length(xcoord)
        xdiff <- V2.xpos-V1.xpos
        
        ## predict the y-coordinates from the x-coordinates
        ycoord.trans <- apply(cbind(V1, V2), 1, function(row){
            ydiff <- row[2]-row[1]
            slope <- ydiff/xdiff
            ypred <- sapply(xcoord[-c(V1.xpos, V2.xpos)], function(y){
                return(slope*(y-V1.xpos)+row[1])
            })
            return(round(ypred,0))
        })
        
        ycoord.trans <- matrix(unlist(ycoord.trans),
                               ncol=length(xcoord[-c(V1.xpos, V2.xpos)]),
                               byrow=TRUE)
        ## get the trans hist for each trans
        trans.block <- NULL
        for (i in 1:ntrans){
            trans.hist <- hist(ycoord.trans[,i], main=paste("Histogram of trans", i, sep=""),
                               xlab=variable.names[2], breaks=break10, plot=hist.plotted, freq=TRUE)
            trans.block <- cbind(trans.block, matrix(rep(trans.hist$counts, xwidth.scale),
                                                     ncol=xwidth.scale))
        }
        
        if (hist.plotted==TRUE){
            V2.hist <- hist(V2, main=paste("Histogram of", variable.names[second], sep=" "),
                            xlab=variable.names[second], breaks=break10, plot=TRUE, freq=TRUE)
            
        }
        ## make the total image block
        image.block <- cbind(image.block, V1.block, trans.block)

        ########################################################
        ##### Step 2: Getting the information for the lines ####
        ########################################################
        
        V1.coord <- V2.coord <- vector()
                                        #????
        V1.breaks <- V1.hist$breaks[-1]
        V2.breaks <- V2.hist$breaks[-1]
        
        
        ## to center the coordinates in the blocks
        V1.coord <- getcoord(V1, V1.breaks) +0.5
        V2.coord <- getcoord(V2, V2.breaks) + 0.5
        coords[[varcol-1]]<- V1.coord
        V1 <- V2
        
    }
    
    ## adding the last variable block at the end
    image.block <- cbind(image.block, V2.block)
    
    ##sort the last columns of information
    ##for the plotting of the lines
    coords[[nvar]]<- V2.coord
    
    ## coordinates of the image block
    col.coord<-1:(dim(image.block)[2]+1)
    row.coord <- 1:(dim(image.block)[1]+1)
    
    ## the plotting device must be able to show a lot of colors...
    ## when I do this from the NCD boxes in Twing it doesn't work
    
    ## IMAGE IS PLOTTED FUNCTION:
    varlabpos <- vector()
    for (i in 1:nvar){
        curpos <- ifelse(i==1, (ntrans*xwidth.scale)/2,
                         (ntrans*xwidth.scale)/2 + 2*(i-1)*ntrans*xwidth.scale )
        varlabpos <- c(varlabpos, curpos)
    }
    
    if (image.plotted==TRUE){
        
        ## display the image plot
        display.imagepl(image.block,V1.hist,
                        varlabpos,
                        variable.names,
                        zlim=range.image,
                        col=color.image,
                        horizontal = horizontal.legend,
                        offset=offset.legend,
                        legend.shrink=legend.shrink,
                        nlevel=nlevel.legend,
                        xlab=xlab.image,
                        ylab=ylab.image,
                        main=title)
    }
    
    line.info <- NULL
    
    
    
    ##superimposed parallel coordinate plot
    
    
############ Plotting the lines: JOINTLY
    
    ## sort each element of the list starting with the last element
    ## if there are duplicates in the prior element of the list
    ## using unique and which and sort(..partial=which())
    
    
    ##1  sort the list
    
    ##2 table(list(coords))
    ##3 unique(coords.mat)
    ##4 tab[tab!=0]
    ##5 final output
    
    ## an example
    ## coords.mat <- cbind(c(1,1,1,1,2,2,2,2), c(1,2,3,4,3,3,2,2), c(1,1,1,1,6,7,8,9))
    ## coords.mat <- rbind(coords.mat, coords.mat[3:5,], coords.mat[4:6,])
    ## coords <- list(coords.mat[,1], coords.mat[,2], coords.mat[,3])
    
    
    ## sort the last element of the list
    sort.pos <- sort(coords[[nvar]], decreasing=FALSE, index.return=TRUE)$ix
    coords <- sortL(coords, sort.pos)
    tab <- table(coords)
    coords.mat <- matrix(unlist(coords), ncol=nvar)
    var.pat <- unique(coords.mat)
    
    dim.name <- labels(tab)
    num.types <- lapply(dim.name, function(w){length(w)})
    ## get the position of the row in the
    ## corresponding element in the list dim.name
    
    dimensions <- t(apply(var.pat, 1, function(row){
        pos <- getPos(row, dim.name)
        
    }))
    
    ## convert the dimensions into the real positions in a vector
    ## please note that R converts lists and matrices into vectors
    ## by column, or else this following procedure will be wrong!
    real.pos <- NULL
    for (row in 1:(dim(dimensions)[1])){
        value <- dimensions[row,1]
        mult <- 1
        for (i in 1:(length(num.types)-1)){
            mult <- mult*num.types[[i]]
            value <- value + (dimensions[row,i+1]-1)*mult
        }
        real.pos <- c(real.pos, value)
    }
    
    ## transform the table into a vector: R does this
    ## by column (not by row...) using as.vector
    
    tab.vec <- as.vector(tab)
    num.lines <- tab.vec[real.pos]
    
    line.info<- cbind(var.pat, num.lines)
    
    ## get the max number of lines
    max.size <- max(num.lines)
    min.size <- min(num.lines)
    
    info <- list()
    lines.ls <- list()
    first.var <- line.info[,1]
    
    for (pair in 2:(dim(var.pat)[2])){
        second.var <- line.info[,pair]
        info[[pair-1]] <- cbind(first.var, second.var, num.lines)
        lines.ls[[pair-1]] <- num.lines
        first.var <- second.var
    }
    
    plotLine(max.size, min.size, range.var = range.var, info=info, varlabpos, lwd.vec, lty.vec, col.vec,
             lines.plotted= lines.plotted, legend.plotted = legend.plotted, bg=color.image[1],
             lines.ls, image.plotted=image.plotted)
         
        
    ## real parallel coordinates
    if(para.plotted==TRUE){
        parallelCoordinates(x,
                            varlabpos=varlabpos, variable.names=variable.names,
                            at.y=round(V1.hist$breaks, 1)[-1], superimpose=FALSE)
        
        box()
        title(main = title, font.main = 4)
        abline(v=varlabpos)
    }
    if (is.null(line.info)==TRUE){
        return(list(image.block=image.block, breaks=break10))
    } else{
        return(list(image.block=image.block, line.info=line.info, breaks=break10))
    }
}



