  WLR.flowcytest <- function(controldata, stimuldata,
                             title="",
                             varname="",
                             na.action.WLR=options()$na.action,
                             rho.test=0,
                             WLR.plotted=TRUE,
                             MY.DEBUG=TRUE){
    

    controldata <- unlist(controldata)
    stimuldata <- unlist(stimuldata)
    if (MY.DEBUG){
      cat("FLOWCYTEST: Weighted Log Rank Test", "\n")
    }
    fluorescence <- c(controldata, stimuldata)
    experimental.status <- c(rep(0, length(controldata)), rep(1, length(stimuldata)))
    
    my.dataframe <- data.frame(fluorescence=fluorescence, experimental.status=experimental.status)
    if (MY.DEBUG){
      cat("\n\n","experimental.status=0 (control)", "\n")
      cat(" experimental.status=1 (stimulated)", "\n\n")
    }
    test <- survdiff(Surv(fluorescence)~experimental.status, data=my.dataframe, na.action=na.action.WLR, rho=rho.test)
    if (MY.DEBUG){
      print(test)
    }
    if (WLR.plotted){
      plot(survfit(Surv(fluorescence)~experimental.status, data=my.dataframe),
           main=paste(title, "Survival Curve", sep=":"), xlab=varname,
           ylab=paste("Proportion beyond", varname, sep=" "), col=c(2,"blue"),
           lty=c(2,3), legend.text=c("control", "stimulated"))
    }
    if (MY.DEBUG){
      cat("\n\n\n")
    }
    return(list(p.val.1sid.chisq.WLR=pchisq(test$chisq, df=1, lower.tail=FALSE),
           chisq.WLR=test$chisq, n.WLR=test$n,
           obs.WLR=test$obs,
    exp.WLR=test$exp, var.WLR=test$var))
   
  }
