require("methods")
## ===========================================================================
## show method for FCSsummary
## ---------------------------------------------------------------------------
setMethod("show",
          signature(object="FCSsummary"),
          function(object){
            cat("\n",
                "I. Data reports:",
                "\n\n")
            cat(paste("   A. Dimension Check: Dimensions: (row X col):",
                      object@num.cells, "X",
                      object@num.param,
                      "\n",
                      sep=" "))
            
            cat(paste("\n",
                      "   B. Data Column Names & Univariate Summary:",
                      "\n",
                      sep=""))
            cat("    Using Tukey's method for the five number summary", "\n")
            print(object@univariate.stat)
            cat("\n")
          
        
            cat("\n",
                "II. Metadata Variable/Slot reports:",
                "\n")
            
            cat("   A. Metadata Slots:",
                "\n")
           
            
            print(object@metadata.info$Description)
            cat("\n")
           
            print(object@metadata.info$ColumnParametersSummary)
            cat("\n")
            
            cat("   B. Metadata 'fcsinfo' slot length=",
               length(object@metadata.info$fcsinfoNames),
                " & slot names: \n\n")
            
         
            print(object@metadata.info$fcsinfoNames)

           
            cat("\n")
           
          })

## ===========================================================================
## print method for FCSsummary
## ---------------------------------------------------------------------------
setMethod("print",
          signature(x="FCSsummary"),
          function(x,...){
            show(x)

          })
## ===========================================================================
## summary method for FCSsummary
## ---------------------------------------------------------------------------
setMethod("summary",
          signature(object="FCS"),
          function(object,...) {
            
            cat("\n")
            cat("I. Data reports:\n\n")
            if (length(as.vector(object@data))==0){
              cat("No Data", "\n\n")
              ranges.data <- NULL
              n.col <- n.row <- 0
            } else {
              if (length(as.vector(object@data))==1) {
                if (is.na(object@data)){
                  cat("No Data", "\n")
                  ranges.data <- NULL
                  n.col <- n.row <- 0
                } else {
                  cat("Single data value=",
                      as(object@data, "matrix"),
                      "\n\n")
                  ranges.data <- range(object@data)
                  n.col <- n.row <- 1
                }
              } else {
                n.row <- dim.FCS(object)[1]
                n.col <- dim.FCS(object)[2]
                
                cat(paste("   A. Dimension Check: Dimensions: (row X col):",
                          n.row, "X",
                          n.col,
                          "\n",
                          sep=" "))
                
                cat(paste("\n",
                          "   B. Data Column Names & Univariate Summary:",
                          "\n",
                          sep=""))
                cat("    Using Tukey's method for the five number summary",
                   "\n")
                ranges.data <- t(apply(object@data, 2,
                                       function(x) {
                                         round(c(fivenum(x),
                                                 mean(x),
                                                 sd(x)), 3)
                                       }))
                
                ranges.data <- cbind(1:length(ranges.data[,1]),
                                     ranges.data)
                colnames(ranges.data) <- c("column", "min",
                                           "lower-hinge", "median",
                                           "upper-hinge", "max", "mean", "sd")
                print(ranges.data)
                cat("\n")
              }
            }
            cat("\n",
                "II. Metadata Variable/Slot reports:",
                "\n")
            
            cat("   A. Metadata Slots:",
                "\n")
            slotnames <- c("mode",
                           "size/$TOT",
                           "nparam/$PAR",
                           "shortnames/$PnN",
                       "longnames/$PnS",
                           "paramranges/$PnR",
                           "filename",
                       "objectname",
                           "original",
                           "fcsinfo")
            description <- c("Mode",
                             "number of cells/rows",
                             "number of column params",
                             "Shortnames of column parameters",
                             "Longnames of column parameters",
                             "Ranges/max of column parameters",
                             "original FCS filename",
                             "name of current object",
                             "current object original status",
                             "misc. metadata info")
            
            values <- c(object[["mode"]],
                        object[["size"]],
                        object[["nparam"]],
                        "see below",
                        "see below",
                        "see below",
                        object[["filename"]],
                        object[["objectname"]],
                        object[["original"]],
                        "see part II B.")
            tot.info <- data.frame(cbind(slotnames, description, values))
            print(tot.info)
            cat("\n")
            col.stuff <- cbind(object[["shortnames"]],
                               object[["longnames"]],
                               object[["paramranges"]])
            colnames(col.stuff) <- c("$PnN", "$PnS", "$PnR")
            col.stuff <- list("ColumnParametersSummary"=col.stuff)
            print(col.stuff)
            cat("\n")
            
            cat("   B. Metadata 'fcsinfo' slot length=",
                length(object@metadata@fcsinfo), " & slot names: \n\n")
            
           
            fcsinfo.stuff <- list("fcsinfoNames"=names(object[["fcsinfo"]]))
                              
          
            print(fcsinfo.stuff)

            if (is.null(ranges.data)){
              ranges.data <- matrix()
            }
            
            cat("\n")
            result <- new("FCSsummary", num.cells=n.row, num.param=n.col,
                           univariate.stat=ranges.data,
                           metadata.info=c("Description"=list(tot.info), col.stuff, fcsinfo.stuff))
            ## MIXING S3 and S4
            ## class(result) <- "summary.FCS"

            ## now there is no mixing of the S3 and S4 classes
            invisible(result)
          })

                                        #setMethod("initialize",
                                        #          signature(.Object="FCS"),
                                        #          function(.Object) {
                                        #            ## test
                                        #          })
