pairs.CSP <- function(x,
                      status=NULL,
                      box.idx.list=NULL,
                      type.CSP=c("count.diff", "p.hat", "p.hat.norm", "z.stat"),
                      alternate.hexbinplot=FALSE,
                      n.hexbins=100,
                      range.x=range(x),
                      varlabpos=round(seq(range.x[1],
                        ceiling(diff(range.x)/150)*150+range.x[1],
                        by=150),0),
                      cutoffs = seq(range.x[1],
                        ceiling(diff(range.x)/25)*25+range.x[1],
                        by=25),  

                      labels = colnames(x),

                      panel = ContourScatterPlot,
                      main="",
                    
                      image.col=heat.colors(10),
                      numlev=5,...,
                      lower.panel = legend.CSP,
                      upper.panel = panel,
                      overlay.panel=rect.box.idx,
                      border.boxes=1:length(box.idx.list),
                      lwd.boxes=rep(3,length(box.idx.list)),
                      lty.boxes=rep(1,length(box.idx.list)),
                      label.pos = 0.5,
                      cex.labels = NULL,
                      font.labels = 1,
                      row1attop = TRUE,
                      gap=1,
                      ch.col=c("heat.colors(n)",
                        "rainbow(n, start=.7, end=.1)",
                        "terrain.colors(n)",
                        "topo.colors(n)",
                        "cm.colors(n)")
                      ) {

    ## 1.  plot legend on another page
    ## 2.  change num.bins=100

  
    ## x is the matrix of data
    ## alternate: if true then does not use pairs plot

    ## there is still an issue with the legend... it is hard to get one.
    ## may want to consider rewriting plot.hexbin

    ## to get a hexbin parallel coordinates plot
  
    ch.col <- match.arg(ch.col)
    lib.there <- require(hexbin)
    if (lib.there==TRUE){
        if(alternate.hexbinplot==TRUE){
      
            panel.hex <- function(x, y) {
                bin <- hexbin(x,y,xbins=n.hexbins)
                plot(bin)
                ##grid.hexagons(bin, maxcnt=max(bin$count),...)
                if (!is.null(box.idx.list)){
                    for (i in 1:length(box.idx.list)){
                        overlay.panel(x, y,
                                      box.idx = box.idx.list[[i]],
                                      border=border.boxes[i],
                                      lwd=lwd.boxes[i], lty=lty.boxes[i])
            
                    }
                }
            }
      
            ## put histograms on the diagonal
            panel.hist <- function(x, ...) {
                usr <- par("usr"); on.exit(par(usr))
                par(usr = c(usr[1:2], 0, 1.5) )
                h <- hist(x, breaks=length(varlabpos), right=FALSE, plot = FALSE)
                breaks <- h$breaks; nB <- length(breaks)
                y <- h$counts; y <- y/max(y)
                rect(breaks[-nB], 0, breaks[-1], y)
                ## text(breaks[-nB]+5, y, labels=as.character(h$counts))
         
                y.seq <- round(seq(0, max(h$counts), by=max(h$counts)/10),0)
                y.s <- y.seq/max(y.seq)
      
                odd.num <- 1:length(y.s)
                odd.num <- odd.num[(odd.num %%2)==1]
                axis(2, at=y.s[odd.num], labels=as.character(y.seq)[odd.num])
            }
      
            pairs(x,
                  labels,
                  panel=panel.hex,
                  diag.panel=panel.hist,
                  cex.labels=cex.labels,
                  font.labels=font.labels,
                  row1attop=row1attop, gap=gap)
  
        } else {
            ##initialize
      
            par(mfrow=c(1,1))
            col.ln <- dim(x)[2]
            varnames <- colnames(x)
    
            par(mfrow=c(col.ln, col.ln))

            par(mar=c(.5,1, .5, 0))
            par(omi=c(1,1,1,1))
 
            for (row in 1:col.ln) {
                for (col in 1:col.ln) {
          
                    if (row==col){
                        xvar <- x[,row]
            
                        usr <- par("usr"); on.exit(par(usr))
                        par(usr = c(usr[1:2], 0, 1.5) )
                        h <- hist(xvar, breaks=length(varlabpos), right=FALSE, plot = FALSE)
                        breaks <- h$breaks; nB <- length(breaks)
                        y <- h$counts; y <- y/max(y)
                        y.seq <- round(seq(0, max(h$counts), by=max(h$counts)/10),0)
                        y.s <- y.seq/max(y.seq)
                        odd.num <- 1:length(y.s)
                        odd.num <- odd.num[(odd.num %%2)==1]
            
                        unit.diff <- max(diff(y.s[odd.num]))
                        plot(0,0,type="n", xlim=range(varlabpos),
                             ylim=c(0,max(y.s)+unit.diff), xaxt="n", yaxt="n")
                        rect(breaks[-nB], 0, breaks[-1], y)

                        axis(2, at=y.s[odd.num], labels=as.character(y.seq)[odd.num])
            
                        var.nm <- varnames[col]
                        var.nm <- ifelse(is.na(var.nm), paste("Column Variable", row, sep=" "), var.nm)
           
      
                        text(mean(range(varlabpos)),y.s[length(y.s)], 
                             var.nm)
            
        
                        box()
                    } else {
            
                        type.CSP <- match.arg(type.CSP)
                        xvar <- x[,col]
                        yvar <- x[,row]
            
                        if (identical(legend.CSP, lower.panel)==TRUE){
                            expression1 <- col > row
              
                        } else {
                            expression1 <- TRUE
              
                        }
                        if (expression1){
                            par(mar=c(.5,1, .5, 0))
              
                            upper.panel(xvar,yvar, status=status,type.CSP=type.CSP,
                                        xlim=range(varlabpos),
                                        ylim=range(varlabpos),
                                        main=main, x.grid=cutoffs,
                                        y.grid=cutoffs,
                                        hexbin.plotted=FALSE,
                                        image.col=image.col,
                                        numlev=numlev,
                                        xaxt="n",
                                        yaxt="n", plot.legend.CSP=FALSE,...)

                            if (!is.null(box.idx.list)){
                                for (i in 1:length(box.idx.list)){
                                    overlay.panel(xvar, yvar,
                                                  box.idx = box.idx.list[[i]],
                                                  border=border.boxes[i],
                                                  lwd=lwd.boxes[i], lty=lty.boxes[i])
                  
                                }
                                ## legend(min(xvar), max(yvar), paste("Box", 1:length(box.idx.list)), col=1:length(box.idx.list),
                                ##        lwd=rep(3, length(box.idx.list)), lty=rep(1, length(box.idx.list)))
                            }
              
                            ##   hexagons(bin, maxcnt=max(bin$cnt))
                            ## if the dimension is 2 variables
                            ##plot the axes
                            if ((dim(x)[2])==2){
                                if (row==1){
                                    axis(3, at=varlabpos)
                                    axis(4, at=varlabpos)
                                } else {
                                    axis(1, at=varlabpos)
                                    axis(2, at=varlabpos)
                                }
                            }
                            ## plot y-axis
                            ## first column, odd row numbers (2=left)
                            ## last column, even row numbers (4=right)
                            if ( (col==1) & ((row %% 2)==1)){
                                axis(2, at=varlabpos)
                            } 
                            if ( (col==col.ln) & ((row %% 2)==0)){
                                axis(4, at=varlabpos)
                            }
              
                            ## plot x-axis
                            ## first row, odd column numbers (3=top)
                            ## last row, even column numbers (1=bottom)
                            if ( (row==1) & ((col %% 2)==1)){
                                axis(3, at=varlabpos)
                            }
                            if ( (row==col.ln) & ((col %% 2)==0)){
                                axis(1, at=varlabpos)
                            }

                            if ((col.ln %% 2)==1){ ##if odd
                                ## plot x axis on last row 1st column, 1=bottom
                                if ( (row==col.ln) & (col==1)){
                                    axis(1, at=varlabpos)
                                }
                
                                ## plot y axis on 1st row last column, 4=left
                                if ( (row==1) & (col==col.ln)){
                                    axis(4, at=varlabpos)
                                }
                            }
                            ## put some ticks
                            axis(1, at=varlabpos, labels=FALSE)
                            axis(2, at=varlabpos, labels=FALSE)
                        } else {
                            ## row < col
                            if (is.null(status)){
                                z <- make.grid(xvar, yvar)$z
                            } else {
                
                                z <- make.density(xvar, yvar, status=status, type.CSP=type.CSP)$z
                            }
                            lower.panel(z, length(image.col), ch.col=ch.col, main="")
                        }
           
                    }
                }
       
            }
      
      
        }
    }
}



