plotQA.FCS<- function(data,varpos=c(1,2),FUN1=IQR,FUN2=NULL,col="row",nrow=8,ncol=12,ind=c(1:96),labeling=TRUE,...){

    ## Test arguments
    npar <- length(varpos)
    if(npar==1 && is.null(FUN2)){
        stop("input 'FUN2' must not be NULL if 'vapors' is of length 1")
    }
    if(npar==2 && !is.null(FUN2)){
        warning("If two parameters are compared, the same descriptor must be used for both (default FUN1).")
    }
    if((!is(data, "cytoSet")) && (!is(data[[1]],"FCS"))){
        stop("input 'object' must be a cytoSet object or a list of FCS objects")
    }
    if((col!="row") && (col!="col")){
        stop("input 'color' must either be by 'row' or by 'col'")
    }

    ## Define the functions to be applied
    FUN1 <- match.fun(FUN1)
    if(npar==2) FUN2 <- FUN1 <- match.fun(FUN1)
    if(npar==1) FUN2 <- match.fun(FUN2)
   
    
    ## color panel 
    colori <- colors()[c(24,27,41,48,56,69,76,84,91,116,126,139)]
    
   
    if(class(data)=="cytoSet"){
        fichier <- as.character(phenoData(data)$name)
    }
    else{
        fichier <- names(data)
    }
    
    ## Order by name
    y <- vector(mode="list",length=length(data))
    x <- vector(mode="list",length=length(data))
    ## Extract intensity values
    if(is(data,"cytoSet")){    
        for (i in 1:length(data)){
            y[[i]] <- exprs(data[[i]])[,varpos[1]]
            if (npar==2){
                x[[i]] <- exprs(data[[i]])[,varpos[2]]
            }
        }
    }
    if(is(data[[1]],"FCS")){
        for (i in 1:length(data)){
            y[[i]] <- fluors(data[[i]])[,varpos[1]]
            if(npar==2){
                x[[i]] <- fluors(data[[i]])[,varpos[2]]
            }
        }
    }

    names(y) <- fichier
    if(!is.null(x)) names(x) <- fichier

    
    if (npar==1){
        x <- y
        y <- unlist(lapply(y,function(z)FUN1(z)))
        x <- unlist(lapply(x,function(z)FUN2(z)))
    }
    else{
        y <- unlist(lapply(y,function(z)FUN1(z)))
        x <- unlist(lapply(x,function(z)FUN1(z)))
    }
    
    ## Define color display
    if(col=="row") {
        color <- rep(colori[1:nrow],each=ncol)
        col.leg <-colori[1:nrow]
        text.title <- "by row"
        text.leg <- c(1:nrow)
    }
    if(col=="col") {
        color <-rep(colori[1:ncol],times=nrow)
        col.leg <-colori[1:ncol]
        text.title <- "by column"
        text.leg <- c(1:ncol)
    }
    
    nbwell <- nrow*ncol
    indwell <- 1:nbwell
    if(length(ind)!=nbwell) {
        color <- color[indwell%in%ind]
    }
    
    ##if(!is.null(fileset)) text.title <- c(paste(fileset,text.title,sep=" "))
    plot(x, y,col=color,type="p",...)
    ##title(text.title,cex=0.5)
    if(labeling) {
        text(x+.4, y+.4,as.character(fichier),cex=0.5)##to me more flexible
    }
}

