read.series.FCS <- function(fcsfiles=NULL,path=NULL,ext=NULL,...) {
    ## Read FCS  (Flow Cytometry Standard) file
    ## Nolwenn Le Meur
    ## 19 Sept 2005.  Last revised 20 Sept 2005.
 
    ## Example:
    ##   read.series.FCS(datafile[1:3])    

    if(is.null(fcsfiles)) {
        if(is.null(path)) path <- "."
        if(!is.null(ext)){
            fcsfiles <-dir(path=path,pattern=c("[[:alnum:]]",ext,"$"))
        }
                                        #if(!is.null(path)) fcsfiles <- file.path(path,fcsfiles)
        nfiles <- length(fcsfiles)
        if(nfiles == 0) stop("Cannot find FCS file")
    }
    
    fcsfiles <- as.character(fcsfiles)
    nfiles <- length(fcsfiles)
    series <- list()
    badFiles <- vector(mode="character", length=0)
    numOK <- 0

    for (i in 1:nfiles) {
        fcsname <- fcsfiles[i]
        if(!is.null(ext)) {
            if (length(grep(ext,fcsname))==0) fcsname <- paste(fcsname,ext,sep=".")
        }
        fullname <- fcsname
        ##print(fcsname) 
        if(!is.null(path)) fullname <- file.path(path,fcsname)
        fcsread <- try(read.FCS(fullname,...))
        if(inherits(fcsread,"try-error")) {
            badFiles<-c(badFiles, fcsname)
        } else {
            numOK <- numOK + 1
            series[[numOK]]<- fcsread
            names(series)[[numOK]] <- fcsfiles[i]
        }

    }
    cat(paste(numOK, "fcs files read \n"))
    if (length(badFiles) > 0) {
        warning("Unable to read the following files:\n",
                paste(badFiles, collapse="\n"))
    }
    return(series)
    
}

