\name{"FCSmetadata-class"}
\docType{class}
\alias{"FCSmetadata-class"}
\alias{"FCSmetadata"}
\alias{FCSmetadata-class}
\alias{FCSmetadata}

\alias{"[-methods",FCSmetadata-method}
\alias{"[<--methods",FCSmetadata-method} 
\alias{"[[-methods",FCSmetadata-method} 
\alias{"[[<--methods",FCSmetadata-method}
\alias{"print-methods",FCSmetadata-method} 
\alias{"show-methods",FCSmetadata-method}
\alias{"summary-methods",FCSmetadata-method} 

\alias{"[",FCSmetadata-method}
\alias{"[<-",FCSmetadata-method}
\alias{"[[<-"-methods,FCSmetadata-method}

\alias{[-methods,FCSmetadata-method}
\alias{[<--methods,FCSmetadata-method} 
\alias{[[-methods,FCSmetadata-method} 
\alias{[[<--methods,FCSmetadata-method}
\alias{print-methods,FCSmetadata-method} 
\alias{show-methods,FCSmetadata-method}
\alias{summary-methods,FCSmetadata-method}

\alias{[,FCSmetadata-method}
\alias{[<-,FCSmetadata-method} 
\alias{[[,FCSmetadata-method} 
\alias{[[<-,FCSmetadata-method}
\alias{print,FCSmetadata-method} 
\alias{show,FCSmetadata-method}
\alias{summary,FCSmetadata-method}

\title{Class "FCSmetadata" Metadata portion of a Flow Cytometry Standard
object}
\description{Information from the HEADER and TEXT of a raw binary FCS
  file about the data and other parameters are stored in the metadata. }
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("FCSmetadata", ...)}.
  
}
\section{Slots}{
  \describe{
    \item{\code{mode}:}{Object of class \code{"character"} the "\$MODE" mode of
      the raw binary FCS file}
    \item{\code{size}:}{Object of class \code{"numeric"} the "\$TOT" row
      dimension of the data; describing the number of observations or
      cells }
    \item{\code{nparam}:}{Object of class \code{"numeric"} the "\$PAR" column
      dimension of the data; describing the number of parameters }
    \item{\code{shortnames}:}{Object of class \code{"vector"} the "\$PnN"
      short names corresponding to the column variables of the data; these
      names are generally non-descript and are not used as the names of the
      columns of the data}
    \item{\code{longnames}:}{Object of class \code{"vector"} the "\$PnS"
      long names used for the column variables of the data}
    \item{\code{paramranges}:}{Object of class \code{"vector"} the
      "\$PnR" maximum value corresponding to the column variables}
    \item{\code{filename}:}{Object of class \code{"character"} path and/or
      name of the \bold{original} raw binary FCS object  }
    \item{\code{objectname}:}{Object of class \code{"character"} the
      name of the original, \code{FCS-class} object}
    \item{\code{original}:}{Object of class \code{"logical"} the
      original status of the current object }
    \item{\code{fcsinfo}:}{Object of class \code{"list"} the other
      parameters and values in the HEADER and TEXT of the raw binary FCS
      file }
  }
}
\section{Methods}{
  \describe{
    \item{"["}{\code{signature(x = "FCSmetadata")}: Extracts the metadata
      slots or metadata@fcsinfo slots by using a single character name
      index; Extracts the metadata@fcsinfo slots by using a single or
      vector of numerical indicies  }

    \item{"[<-"}{\code{signature(x = "FCSmetadata")}: Replaces the metadata
      slots or metadata@fcsinfo slots by using a single character name
      index; Replaces the metadata@fcsinfo slots by using a single or
      vector of numerical indicies;Adds a new slot to the
      metadata@fcsinfo }
    
    \item{"[["}{\code{signature(x = "FCSmetadata")}:  Extracts the metadata
      slots or metadata@fcsinfo slots by using a single character name
      index; Extracts the metadata@fcsinfo slots by using a single or
      vector of numerical indicies }
    
    \item{"[[<-"}{\code{signature(x = "FCSmetadata")}: Replaces the metadata
      slots or metadata@fcsinfo slots by using a single character name
      index; Replaces the metadata@fcsinfo slots by using a single or
      vector of numerical indicies;Adds a new slot to the
      metadata@fcsinfo}
    
    \item{"print-methods"}{\code{signature(x = "FCSmetadata")}: prints the
      original status, the objectname, filename, and dimensions of the
      data}
    
    \item{"show-methods"}{\code{signature(object = "FCSmetadata")}: same as 'print' }

    \item{"summary-methods"}{\code{signature(object = "FCSmetadata")}: summaries
      the metadata in a string output }
  }
}
\references{   Trevor Hastie, Robert Tibshirani, and Jerome Friedman. The
  Elements of Statistical Learning: Data Mining, Inference, and
  Prediction. Springer Series in Statistics : New York, 2001. pp.279-283.

  Jerome H. Friedman and Nicholas I. Fisher. Bump Hunting in
  High-Dimensional Data. Tech Report. October 28, 1998.

  J. Paul Robinson, et al. Current Protocols in Cytometry.  John Wiley
  \& Sons, Inc : 2001.

  Mario Roederer and Richard R. Hardy. Frequency Difference Gating: A
  Multivariate Method for Identifying Subsets that Differe between
  Samples. Cytometry, 45:56-64, 2001.

  Mario Roederer and Adam Treister and Wayne Moore and Leonore
  A. Herzenberg. Probability Binning Comparison: A Metric for
  Quantitating Univariate Distribution Differences. Cytometry, 45:37-46,
  2001.

  Keith A. Baggerly. Probability Binning and Testing Agreement between
  Multivariate Immunofluorescence Histograms: Extending the Chi-Squared
  Test. Cytometry, 45:141-150, 2001.
}
\author{A.J. Rossini, J.Y. Wan, and Zoe Moodie}

\note{
  For more information about the different parameters in the
  metadata@fcsinfo slot, please look at the documentation for
  \code{read.FCS}.
}
\seealso{
  \code{\link{read.FCS}}, 
  \code{\link{"FCS-class"}},
  \code{\link{"print-methods"}},
  \code{\link{"show-methods"}},
  \code{\link{"summary-methods"}},
  \code{\link{"[-methods"}},
  \code{\link{"[[-methods"}},
  \code{\link{"[<--methods"}},
  \code{\link{"[[<--methods"}}
}
\examples{
default<-new("FCSmetadata")

some.meta<-new("FCSmetadata", fcsinfo=list("comment"=rep("none", 10)),
mode="none", nparam=0, size=0)

## extract/subset the metadata
some.meta[["nparam"]]
some.meta["paramranges"]
## replace the metadata/subsetassign the metadata
## 3 parameters with ranges
some.meta[["nparam"]]<-3
some.meta["paramranges"]<-rep(1,3)
## show
show(some.meta)
## print
print(some.meta)
some.meta
## summary
summary(some.meta)
}
\keyword{classes}
