\name{VRC.HVTNFCS}
\alias{VRC.HVTNFCS}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Sequential Gating Scheme from Vaccine Research Center
  (VRC), NIH, Bethesda, MD; Mario Roederer, PhD}
\description{

  This function uses \code{\link{icreateGate}} and \code{\link{createGate}} to
  select the datapoints which are of particular interest.  The selection
  process is realized in an index column which is added to the data of
  the FCS object.  In particular, after a series of gating/datapoint
  selection sequences, the interferon gamma variable is of interest.

  To row reduce the data of the FCS object, the function,
  \code{\link{extractGatedData}} should be used on the last gate index to
  obtain the rows/cells and then should be used again to subset
  across columns to obtain the gamma interferon column.

}
\usage{

VRC.HVTNFCS(myFCSobj, gate1.vars = c(1, 2), gate2.vars = c(7, 5),
                 gate3.vars = c(5, 3),MY.DEBUG = FALSE)

}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{myFCSobj}{a FCS object}
  \item{gate1.vars}{The vector of column variable positions
    corresponding to Forward Scatter and Side Scatter variables for the
    first gate; default
    is column positions 1 and 2 respectively}
  \item{gate2.vars}{The vector of column variable positions
    corresponding to cd3 and cd4 variables for the
    second gate; default is column positions 7 and 5 respectively}
  \item{gate3.vars}{The vector of column variable positions
    corresponding to cd4 and cd8 variables for gate 3;
    default is column positions 5 and 3 respectively}
  \item{MY.DEBUG}{if TRUE, then will print the debugging statements;
    otherwise, if FALSE, then will surpress the debugging statements;
    default is FALSE}
}
\details{

  The Selection Sequence proposed by Mario Roederer is the following:
  \describe{
  \item{\bold{gate1:bipcut:}}{ Forward Scatter VS Side Scatter
  (Select the lymphocytes--central cluster) }

  \item{\bold{gate2:bidcut:}}{ cd3 VS cd4 (want cd3+ cells)
  (Select the cd3 positive cells on the right of the cutoff)}

  \item{\bold{gate3:biscut:}}{ cd4 vs cd8 
      gate 3.1: (Select cd4+/cd8- cells)  (+/- quadrant)
      gate 3.2: (Select cd4-/cd8+ cells)  (-/+ quadrant)}
  }
  In General, Types of Gating/Cutting:
  \describe{
  \item{uniscut = univariate single cut}{
  (Selection of the positive/right half)}
  
  \item{biscut = bivariate single cut}{
  (Selection of the +/-, -/-. +/+, or -/+ quadrant)}
  
  \item{bidcut = bivariate double cut}{
  (Selection of the center rectangle
  that results)}
  }
}
\value{
 
  \item{FCS object}{ with the following slots:}
    \item{data}{A augmented dataframe with the added-on gating column variables/indices}
    \item{metadata}{a FCSmetadata object with the information about the
      gating column variables: \$PnR (gating range), \$PnN
      (gating variable's shortname/unused name in the data of the FCS
      object), \$PnS (gating variable's longname/used name), and other slot information}
}

\references{Mario Roederer, PhD}
\author{A.J. Rossini \& J.Y. Wan}
\note{
  The "VRC" data from the "rfcdorig" package can be used for this sequential
  gating scheme.  
}

\section{WARNING }{This gating scheme is not standard, and there may
  have been changes to the gating scheme.  This gating scheme only
  serves as an example, which demonstrates the use of
  \code{\link{createGate}},\code{\link{icreateGate}}
  and \code{\link{extractGateHistory}} which extracts the gating information
  (eg. in order to obtain information about a previous gating
  index/column variable)}

\seealso{ \code{\link{createGate}}, \code{\link{icreateGate}},
  \code{\link{FHCRC.HVTNFCS}}, \code{\link{plotvar.FCS}},
  \code{\link{extractGatedData}}, \code{\link{extractGateHistory}}
}
  

\examples{

if (require(rfcdmin)){

data.there<-is.element(c("st.1829", "unst.1829", "st.DRT", "unst.DRT"),objects())
if ( ( sum(data.there) != length(data.there) )){
## obtaining the FCS objects from VRC data
data(VRCmin)
}




# HIV positive individual
if (interactive()==TRUE){
par(mfrow=c(4,2))
st.DRT.VRC<-VRC.HVTNFCS(st.DRT)
}

}
}
\keyword{iplot}
