\name{plotQA.FCS}
\alias{plotQA.FCS}

\title{Create a scatterplot summaryzing one (or two) parameter(s)
  for several FCS objects stored in a  plate}

\description{
  Create a scatterplot summaryzing one (or two) parameter(s)
  for several FCS objects stored in a  plate. The points are colored according to their position in the plate (row or column number.)
}
\usage{
plotQA.FCS(data,varpos=c(1,2),FUN1=IQR,FUN2=NULL,col="row",nrow=8,ncol=12,ind=c(1:96),labeling=TRUE,...)                      
}

\arguments{
  \item{data}{a list of fluorescent data from one (or more) FCS object(s) or a cytoset}

  \item{varpos}{the numerical column variable position of the data of the FCS object}

  \item{FUN1}{function to summaryze the distribution of the data, e.g. mean, median, IQR, MODE}

  \item{FUN2}{function to summaryze the distribution of the  data e.g. mean, median, IQR, MODE}

  \item{col}{character vector either "row" or "col"}

  \item{nrow}{numeric, number of rows per plate}
  
  \item{ncol}{numeric, number of columns per plate}

  \item{ind}{numeric vector, index of the wells to be plotted}

  \item{labeling}{logical, draw plate position (default=TRUE)}

  \item{...}{any other arguments are passed to the \code{\link{plot}}
   function}
}  


\value{
 None.
}

\author{Nolwenn Le Meur}


\seealso{\code{\link{plot}}}


\examples{
  ##Example I:
 data(flowcyt.data)

 ##Draw a scatterplot of the median values
 ##of the Foward scatter and the Side scatter parameters
 ##of each FCS file. The files correspond to samples store in a 96 well plate.
 plotQA.FCS(flowcyt.data,varpos=c(1,2),FUN1=median,nrow=8,ncol=10,ind=c(1:80),col="row",pch="*",labeling=FALSE,xlim=c(0,300),ylim=c(0,300),main="FSCmedian vs.SSCmedian by row",xlab="SSC median",ylab="FSC median")

 ##Example II:
 ##Draw a a scatterplot of the mode and IQR values for the Foward scatter
 ##of each FCS file. 
 plotQA.FCS(flowcyt.data,varpos=c(1),FUN1=IQR,FUN2=MODE,nrow=8,ncol=10,ind=c(1:80),col="col",pch="*",labeling=TRUE,xlim=c(0,300),ylim=c(0,300),xlab="FSC mode",ylab="FSC IQR",main="FSC IQR vs.FSC mode by column")
 }

\keyword{hplot}
