## StopOnError or else continue through

if ("StopOnError" %in% objects()){
  if (!is.logical(StopOnError)) {
    ## default is TRUE when StopOnError is not boolean
    StopOnError <- TRUE
  }    
} else {
  ## default is to stop when there is an error 
  StopOnError <- TRUE
}


## An example FCS S4 object
if (!require(rfcdmin)){
  library(rfcdmin, lib.loc="~/lib/R")
}
if (!require(rflowcyt)){
  library(rflowcyt, lib.loc="~/lib/R")
}

ErrorMsg <- NULL
FailedTestObjName <- NULL
error.printed <- names.failed <- NULL

ex.s4 <- read.FCS(paste(system.file(package="rfcdmin"),
                        "/fcs/SEB-NP22.fcs", sep=""),
                  FCSobj.name="ex.s4", UseS3=FALSE)
ex.s3 <- read.FCS(paste(system.file(package="rfcdmin"),
                        "/fcs/SEB-NP22.fcs", sep=""),
                  FCSobj.name="ex.s4", UseS3=TRUE)


## Create example and then test:

####  test1 : Gating type: uniscut, univariate single cut
test1 <- createGate(ex.s4, varpos=1, gatingrange=256,
                    type="uniscut", MY.DEBUG=TRUE)

test1.1 <- extractGatedData(test1, gateNum=1,
                            IndexValue.In=1, MY.DEBUG=TRUE)


## what is a good way to test?
min.test1.1 <- unlist(apply(as(test1.1@data, "matrix"), 2, min)[1])
max.test1.1 <- unlist(apply(as(test1.1@data, "matrix"), 2, max)[1])

if (!((min.test1.1 >= 256) & (max.test1.1 <= 1024))){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test1.1 failed: Can't get uniscut with IndexValue.In=1")
  FailedTestObjName <- c(FailedTestObjName, "test1.1")
  if (StopOnError) {
    stop("FCSgateclass: test1.1 failed: Can't set uniscut with IndexValue.In=1\n")
  }
} else {
  cat("FCSgateclass: test1.1 succeeded: Able to get uniscut with IndexValue.In=1.\n")
}


test1.2 <- extractGatedData(test1, gateNum=1, IndexValue.In=0, MY.DEBUG=TRUE)


## what is a good way to test?
min.test1.2 <- unlist(apply(as(test1.2@data, "matrix"), 2, min)[1])
max.test1.2 <- unlist(apply(as(test1.2@data, "matrix"), 2, max)[1])

if (!((min.test1.2 >= 0) & (max.test1.2 < 256))){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test1.2 failed: Can't get uniscut with IndexValue.In=0")
  FailedTestObjName <- c(FailedTestObjName, "test1.2")
  if (StopOnError) {
    stop("FCSgateclass: test1.2 failed: Can't get uniscut with IndexValue.In=0\n")
  }
} else {
  cat("FCSgateclass: test1.2 succeeded: Able to get uniscut with IndexValue.In=0.\n")
}

## test2 : Gating type, biscut,
##  bivariate single cut (two lines: one vertical one horizontal, select quadrant)

## test2.1 biscut quadrant: +/+
test2.1 <- createGate(test1, varpos=c(1,2), gatingrange=c(256, 300),
                    type="biscut", biscut.quadrant="+/+", prev.gateNum=NULL,
                      MY.DEBUG=TRUE)

test2.1.1 <- extractGatedData(test2.1, gateNum=2,
                              IndexValue.In=1, MY.DEBUG=TRUE)


## what is a good way to test?
min.test2.1.1v1 <- apply(as(test2.1.1@data, "matrix"), 2, min)[1]
max.test2.1.1v1 <- apply(as(test2.1.1@data, "matrix"), 2, max)[1]

min.test2.1.1v2 <- apply(as(test2.1.1@data, "matrix"), 2, min)[2]
max.test2.1.1v2 <- apply(as(test2.1.1@data, "matrix"), 2, max)[2]

if (!((min.test2.1.1v1 >= 256) & (min.test2.1.1v2 >=300) & (max.test2.1.1v1 <= 1024) & (max.test2.1.1v2 <= 1024))){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test2.1.1 failed: Can't get biscut +/+, IndexValue.In=1")
  FailedTestObjName <- c(FailedTestObjName, "test2.1.1")
  if (StopOnError) {
    stop("FCSgateclass: test2.1.1 failed: Can't set biscut +/+, IndexValue.In=1\n")
  }
} else {
  cat("FCSgateclass: test2.1.1 succeeded: Able to get biscut +/+, IndexValue.In=1\n")
}

test2.1.2 <- extractGatedData(test2.1, gateNum=2,
                              IndexValue.In=0, MY.DEBUG=TRUE)


## what is a good way to test?
min.test2.1.2v1 <- apply(as(test2.1.2@data, "matrix"), 2, min)[1]
max.test2.1.2v1 <- apply(as(test2.1.2@data, "matrix"), 2, max)[1]

min.test2.1.2v2 <- apply(as(test2.1.2@data, "matrix"), 2, min)[2]
max.test2.1.2v2 <- apply(as(test2.1.2@data, "matrix"), 2, max)[2]

if (((min.test2.1.2v1 >= 256) & (min.test2.1.2v2 >=300) & (max.test2.1.2v1 <= 1024) & (max.test2.1.2v2 <= 1024))){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test2.1.2 failed: Can't get biscut +/+, IndexValue.In=0")
  FailedTestObjName <- c(FailedTestObjName, "test2.1.2")
  if (StopOnError) {
    stop("FCSgateclass: test2.1.2 failed: Can't set biscut +/+, IndexValue.In=0 \n")
  }
} else {
  cat("FCSgateclass: test2.1.2 succeeded: Able to get biscut +/+, IndexValue.In=0\n")
}

## test2.2 biscut quadrant: -/+
test2.2 <- createGate(test1, varpos=c(1,2),
                      gatingrange=c(256, 300),
                      type="biscut",
                      biscut.quadrant="-/+",
                      prev.gateNum=NULL,
                      MY.DEBUG=TRUE)
test2.2.1 <- extractGatedData(test2.2, gateNum=2,
                              IndexValue.In=1, MY.DEBUG=TRUE)


## what is a good way to test?
min.test2.2.1v1 <- apply(as(test2.2.1@data, "matrix"), 2, min)[1]
max.test2.2.1v1 <- apply(as(test2.2.1@data, "matrix"), 2, max)[1]

min.test2.2.1v2 <- apply(as(test2.2.1@data, "matrix"), 2, min)[2]
max.test2.2.1v2 <- apply(as(test2.2.1@data, "matrix"), 2, max)[2]

if (!((min.test2.2.1v1 >= 0) & (min.test2.2.1v2 >=300) & (max.test2.2.1v1 <= 256) & (max.test2.2.1v2 <= 1024))){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test2.2.1 failed: Can't get biscut -/+, IndexValue.In=1")
  FailedTestObjName <- c(FailedTestObjName, "test2.2.1")
  if (StopOnError) {
    stop("FCSgateclass: test2.2.1 failed: Can't set biscut -/+, IndexValue.In=1 \n")
  }
} else {
  cat("FCSgateclass: test2.2.1 succeeded: Able to get biscut -/+, IndexValue.In=1 \n")
}

test2.2.2 <- extractGatedData(test2.2, gateNum=2, IndexValue.In=0, MY.DEBUG=TRUE)


## what is a good way to test?
min.test2.2.2v1 <- apply(as(test2.2.2@data, "matrix"), 2, min)[1]
max.test2.2.2v1 <- apply(as(test2.2.2@data, "matrix"), 2, max)[1]

min.test2.2.2v2 <- apply(as(test2.2.2@data, "matrix"), 2, min)[2]
max.test2.2.2v2 <- apply(as(test2.2.2@data, "matrix"), 2, max)[2]

if (((min.test2.2.2v1 >= 0) & (min.test2.2.2v2 >=300) & (max.test2.2.2v1 <= 256) & (max.test2.2.2v2 <= 1024))){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test2.2.2 failed: Can't get biscut -/+, IndexValue.In=0")
  FailedTestObjName <- c(FailedTestObjName, "test2.2.2")
  if (StopOnError) {
    stop("FCSgateclass: test2.2.2 failed: Can't set biscut -/+, IndexValue.In=0 \n")
  }
} else {
  cat("FCSgateclass: test2.2.2 succeeded: Able to get biscut -/+, IndexValue.In=0 \n")
}



## test2.3 biscut quadrant: -/-
test2.3 <- createGate(test1, varpos=c(1,2),
                      gatingrange=c(256, 300),
                      type="biscut",
                      biscut.quadrant="-/-",
                      prev.gateNum=NULL,
                      MY.DEBUG=TRUE)
test2.3.1 <- extractGatedData(test2.3, gateNum=2,
                              IndexValue.In=1,
                              MY.DEBUG=TRUE)


## what is a good way to test?
min.test2.3.1v1 <- apply(as(test2.3.1@data, "matrix"), 2, min)[1]
max.test2.3.1v1 <- apply(as(test2.3.1@data, "matrix"), 2, max)[1]

min.test2.3.1v2 <- apply(as(test2.3.1@data, "matrix"), 2, min)[2]
max.test2.3.1v2 <- apply(as(test2.3.1@data, "matrix"), 2, max)[2]

if (!((min.test2.3.1v1 >= 0) & (min.test2.3.1v2 >=0) & (max.test2.3.1v1 <= 256) & (max.test2.3.1v2 <= 300))){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test2.3.1 failed: Can't get biscut -/-, IndexValue.In=1")
  FailedTestObjName <- c(FailedTestObjName, "test2.3.1")
  if (StopOnError) {
    stop("FCSgateclass: test2.3.1 failed: Can't set biscut -/-, IndexValue.In=1 \n")
  }
} else {
  cat("FCSgateclass: test2.3.1 succeeded: Able to get biscut -/-, IndexValue.In=1 \n")
}

test2.3.2 <- extractGatedData(test2.3, gateNum=2,
                              IndexValue.In=0,
                              MY.DEBUG=TRUE)


## what is a good way to test?
min.test2.3.2v1 <- apply(as(test2.3.2@data, "matrix"), 2, min)[1]
max.test2.3.2v1 <- apply(as(test2.3.2@data, "matrix"), 2, max)[1]

min.test2.3.2v2 <- apply(as(test2.3.2@data, "matrix"), 2, min)[2]
max.test2.3.2v2 <- apply(as(test2.3.2@data, "matrix"), 2, max)[2]

if (((min.test2.3.2v1 >= 0) & (min.test2.3.2v2 >=0) & (max.test2.3.2v1 <= 256) & (max.test2.3.2v2 <= 300))){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test2.3.2 failed: Can't get biscut -/-, IndexValue.In=0")
  FailedTestObjName <- c(FailedTestObjName, "test2.3.2")
  if (StopOnError) {
    stop("FCSgateclass: test2.3.2 failed: Can't set biscut -/-, IndexValue.In=0 \n")
  }
} else {
  cat("FCSgateclass: test2.3.2 succeeded: Able to get biscut -/-, IndexValue.In=0 \n")
}


## test2.4 biscut quadrant: +/-
test2.4 <- createGate(test1, varpos=c(1,2),
                      gatingrange=c(256, 300),
                      type="biscut",
                      biscut.quadrant="+/-",
                      prev.gateNum=NULL,
                      MY.DEBUG=TRUE)
test2.4.1 <- extractGatedData(test2.4, gateNum=2,
                              IndexValue.In=1,
                              MY.DEBUG=TRUE)


## what is a good way to test?
min.test2.4.1v1 <- apply(as(test2.4.1@data, "matrix"), 2, min)[1]
max.test2.4.1v1 <- apply(as(test2.4.1@data, "matrix"), 2, max)[1]

min.test2.4.1v2 <- apply(as(test2.4.1@data, "matrix"), 2, min)[2]
max.test2.4.1v2 <- apply(as(test2.4.1@data, "matrix"), 2, max)[2]

if (!((min.test2.4.1v1 >= 256) & (min.test2.4.1v2 >=0) & (max.test2.4.1v1 <= 1024) & (max.test2.4.1v2 <= 300))){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test2.4.1 failed: Can't get biscut +/-, IndexValue.In=1")
  FailedTestObjName <- c(FailedTestObjName, "test2.4.1")
  if (StopOnError) {
    stop("FCSgateclass: test2.4.1 failed: Can't set biscut +/-, IndexValue.In=1 \n")
  }
} else {
  cat("FCSgateclass: test2.4.1 succeeded: Able to get biscut +/-, IndexValue.In=1 \n")
}

test2.4.2 <- extractGatedData(test2.4, gateNum=2,
                              IndexValue.In=0, MY.DEBUG=TRUE)


## what is a good way to test?
min.test2.4.2v1 <- apply(as(test2.4.2@data, "matrix"), 2, min)[1]
max.test2.4.2v1 <- apply(as(test2.4.2@data, "matrix"), 2, max)[1]

min.test2.4.2v2 <- apply(as(test2.4.2@data, "matrix"), 2, min)[2]
max.test2.4.2v2 <- apply(as(test2.4.2@data, "matrix"), 2, max)[2]

if (((min.test2.4.2v1 >= 256) & (min.test2.4.2v2 >=0) & (max.test2.4.2v1 <= 1024) & (max.test2.4.2v2 <= 300))){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test2.4.2 failed: Can't get biscut +/-, IndexValue.In=0")
  FailedTestObjName <- c(FailedTestObjName, "test2.4.2")
  if (StopOnError) {
    stop("FCSgateclass: test2.4.2 failed: Can't set biscut +/-, IndexValue.In=0 \n")
  }
} else {
  cat("FCSgateclass: test2.4.2 succeeded: Able to get biscut +/-, IndexValue.In=0 \n")
}

## test3: bipcut


## gating ranges are in the polygon matrix
## A TRIANGLE
x.coords <- c(200, 500, 700)
y.coords <- c(100, 600, 100)
gating.poly <- c(x.coords, y.coords)
gating.poly.mat <- cbind(x.coords, y.coords)
## gatingrange has to be a vector
test3 <- createGate(test1, varpos=c(5,3),
                    gatingrange=gating.poly,
                    type="bipcut",
                    prev.gateNum=NULL,
                    comment="test3",
                    MY.DEBUG=TRUE)
test3.1 <- extractGatedData(test3, gateNum=2,
                            IndexValue.In=1,
                            MY.DEBUG=TRUE)

##pts <- as(test3.1[,c(5,3)], "matrix")
##all.in.poly <- sum(inout(pts, gating.poly.mat))==test3.1[["size"]]
pts <-cbind(as.numeric(fluors(test3.1[,5])), as.numeric(fluors(test3.1[,3])))
lib.there <- require(prada)
    if (lib.there==FALSE){
      stop("Library prada can not be found but is needed")
    }
all.in.poly <- sum(as.numeric(.Call("inPolygon", pts, gating.poly.mat, PACKAGE="prada")))==test3.1[["size"]]

if (!(all.in.poly)){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test3.1 failed: Can't get bipcut, IndexValue.In=1")
  FailedTestObjName <- c(FailedTestObjName, "test3.1")
  if (StopOnError) {
    stop("FCSgateclass: test3.1 failed: Can't set bipcut, IndexValue.In=1 \n")
  }
} else {
  cat("FCSgateclass: test3.1 succeeded: Able to get bipcut, IndexValue.In=1 \n")
}

test3.2 <- extractGatedData(test3,
                            gateNum=2,
                            IndexValue.In=0,
                            MY.DEBUG=TRUE)

##pts <- as(test3.2[,c(5,3)], "matrix")
##any.in.poly <- sum(inout(pts, gating.poly.mat))==test3.2[["size"]]
pts <-cbind(as.numeric(fluors(test3.2[,5])), as.numeric(fluors(test3.2[,3])))
any.in.poly <- sum(as.numeric(.Call("inPolygon", pts, gating.poly.mat, PACKAGE="prada")))==test3.2[["size"]]

if ((any.in.poly)){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test3.2 failed: Can't get bipcut, IndexValue.In=0")
  FailedTestObjName <- c(FailedTestObjName, "test3.2")
  if (StopOnError) {
    stop("FCSgateclass: test3.2 failed: Can't set bipcut, IndexValue.In=0 \n")
  }
} else {
  cat("FCSgateclass: test3.2 succeeded: Able to get bipcut, IndexValue.In=0 \n")
}

## test4: bidcut

test4 <- createGate(test1, varpos=c(2,4),
                    gatingrange=c(256, 900, 100, 400),
                    type="bidcut",
                    prev.gateNum=NULL,
                    MY.DEBUG=TRUE)
test4.1 <- extractGatedData(test4, gateNum=2,
                            IndexValue.In=1,
                            MY.DEBUG=TRUE)


## what is a good way to test?
min.test4.1v1 <- apply(as(test4.1@data, "matrix"), 2, min)[2]
max.test4.1v1 <- apply(as(test4.1@data, "matrix"), 2, max)[2]

min.test4.1v2 <- apply(as(test4.1@data, "matrix"), 2, min)[4]
max.test4.1v2 <- apply(as(test4.1@data, "matrix"), 2, max)[4]

if (!((min.test4.1v1 >= 256) & (min.test4.1v2 >=100) & (max.test4.1v1 <= 900) & (max.test4.1v2 <= 400))){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test4.1 failed: Can't get bidcut, IndexValue.In=1")
  FailedTestObjName <- c(FailedTestObjName, "test4.1")
  if (StopOnError) {
    stop("FCSgateclass: test4.1 failed: Can't set bidcut, IndexValue.In=1 \n")
  }
} else {
  cat("FCSgateclass: test4.1 succeeded: Able to get bidcut, IndexValue.In=1\n")
}

test4.2 <- extractGatedData(test4, gateNum=2,
                            IndexValue.In=0,
                            MY.DEBUG=TRUE)


## what is a good way to test?
min.test4.2v1 <- apply(as(test4.2@data, "matrix"), 2, min)[2]
max.test4.2v1 <- apply(as(test4.2@data, "matrix"), 2, max)[2]

min.test4.2v2 <- apply(as(test4.2@data, "matrix"), 2, min)[4]
max.test4.2v2 <- apply(as(test4.2@data, "matrix"), 2, max)[4]

if (((min.test4.2v1 >= 256) & (min.test4.2v2 >=100) & (max.test4.2v1 <= 900) & (max.test4.2v2 <= 400))){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test4.2 failed: Can't get bidcut, IndexValue.In=0")
  FailedTestObjName <- c(FailedTestObjName, "test4.2")
  if (StopOnError) {
    stop("FCSgateclass: test4.2 failed: Can't get bidcut, IndexValue.In=0 \n")
  }
} else {
  cat("FCSgateclass: test4.2 succeeded: Able to get bidcut, IndexValue.In=0 \n")
}

## run the checkvars and fixvars on the gated objects
test5.1 <- checkvars(test1)
if (!test5.1){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test5.1 failed: 'checkvars' fails on test1")
  FailedTestObjName <- c(FailedTestObjName, "test5.1")
  if (StopOnError) {
    stop("FCSgateclass: test5.1 failed: 'checkvars' fails on test1 \n")
  }
} else {
  cat("FCSgateclass: test5.1 succeeded: 'checkvars' succeeds on test1 \n")
}
test5.1.1 <- checkvars(test1.1)
if (!test5.1.1){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test5.1.1 failed: 'checkvars' fails on test1.1")
  FailedTestObjName <- c(FailedTestObjName, "test5.1.1")
  if (StopOnError) {
    stop("FCSgateclass: test5.1.1 failed: 'checkvars' fails on test1.1 \n")
  }
} else {
  cat("FCSgateclass: test5.1.1 succeeded: 'checkvars' succeeds on test1.1 \n")
}
test5.1.2 <- checkvars(test1.2)
if (!test5.1.2){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test5.1.2 failed: 'checkvars' fails on test1.2")
  FailedTestObjName <- c(FailedTestObjName, "test5.1.2")
  if (StopOnError) {
    stop("FCSgateclass: test5.1.2 failed: 'checkvars' fails on test1.2 \n")
  }
} else {
  cat("FCSgateclass: test5.1.2 succeeded: 'checkvars' succeeds on test1.2 \n")
}
test5.2.1 <- checkvars(test2.1)
if (!test5.2.1){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test5.2.1 failed: 'checkvars' fails on test2.1")
  FailedTestObjName <- c(FailedTestObjName, "test5.2.1")
  if (StopOnError) {
    stop("FCSgateclass: test5.2.1 failed: 'checkvars' fails on test2.1 \n")
  }
} else {
  cat("FCSgateclass: test5.2.1 succeeded: 'checkvars' succeeds on test2.1 \n")
}
test5.2.1.1 <- checkvars(test2.1.1)
if (!test5.2.1.1){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test5.2.1.1 failed: 'checkvars' fails on test2.1.1")
  FailedTestObjName <- c(FailedTestObjName, "test5.2.1.1")
  if (StopOnError) {
    stop("FCSgateclass: test5.2.1.1 failed: 'checkvars' fails on test2.1.1 \n")
  }
} else {
  cat("FCSgateclass: test5.2.1.1 succeeded: 'checkvars' succeeds on test2.1.1 \n")
}
test5.2.1.2 <- checkvars(test2.1.2)
if (!test5.2.1.2){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test5.2.1.2 failed: 'checkvars' fails on test2.1.2")
  FailedTestObjName <- c(FailedTestObjName, "test5.2.1.2")
  if (StopOnError) {
    stop("FCSgateclass: test5.2.1.2 failed: 'checkvars' fails on test2.1.2 \n")
  }
} else {
  cat("FCSgateclass: test5.2.1.2 succeeded: 'checkvars' succeeds on test2.1.2 \n")
}
test5.2.2 <- checkvars(test2.2)
if (!test5.2.2){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test5.2.2 failed: 'checkvars' fails on test2.2")
  FailedTestObjName <- c(FailedTestObjName, "test5.2.2")
  if (StopOnError) {
    stop("FCSgateclass: test5.2.2 failed: 'checkvars' fails on test2.2 \n")
  }
} else {
  cat("FCSgateclass: test5.2.2 succeeded: 'checkvars' succeeds on test2.2 \n")
}
test5.2.2.1 <- checkvars(test2.2.1)
if (!test5.2.2.1){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test5.2.2.1 failed: 'checkvars' fails on test2.2.1")
  FailedTestObjName <- c(FailedTestObjName, "test5.2.2.1")
  if (StopOnError) {
    stop("FCSgateclass: test5.2.2.1 failed: 'checkvars' fails on test2.2.1 \n")
  }
} else {
  cat("FCSgateclass: test5.2.2.1 succeeded: 'checkvars' succeeds on test2.2.1 \n")
}
test5.2.2.2 <- checkvars(test2.2.2)
if (!test5.2.2.2){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test5.2.2.2 failed: 'checkvars' fails on test2.2.2")
  FailedTestObjName <- c(FailedTestObjName, "test5.2.2.2")
  if (StopOnError) {
    stop("FCSgateclass: test5.2.2.2 failed: 'checkvars' fails on test2.2.2 \n")
  }
} else {
  cat("FCSgateclass: test5.2.2.2 succeeded: 'checkvars' succeeds on test2.2.2 \n")
}
test5.2.3 <- checkvars(test2.3)
if (!test5.2.3){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test5.2.3 failed: 'checkvars' fails on test2.3")
  FailedTestObjName <- c(FailedTestObjName, "test5.2.3")
  if (StopOnError) {
    stop("FCSgateclass: test5.2.3 failed: 'checkvars' fails on test2.3 \n")
  }
} else {
  cat("FCSgateclass: test5.2.3 succeeded: 'checkvars' succeeds on test2.3 \n")
}
test5.2.3.1 <- checkvars(test2.3.1)
if (!test5.2.3.1){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test5.2.3.1 failed: 'checkvars' fails on test2.3.1")
  FailedTestObjName <- c(FailedTestObjName, "test5.2.3.1")
  if (StopOnError) {
    stop("FCSgateclass: test5.2.3.1 failed: 'checkvars' fails on test2.3.1 \n")
  }
} else {
  cat("FCSgateclass: test5.2.3.1 succeeded: 'checkvars' succeeds on test2.3.1 \n")
}
test5.2.3.2 <- checkvars(test2.3.2)
if (!test5.2.3.2){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test5.2.3.2 failed: 'checkvars' fails on test2.3.2")
  FailedTestObjName <- c(FailedTestObjName, "test5.2.3.2")
  if (StopOnError) {
    stop("FCSgateclass: test5.2.3.2 failed: 'checkvars' fails on test2.3.2 \n")
  }
} else {
  cat("FCSgateclass: test5.2.3.2 succeeded: 'checkvars' succeeds on test2.3.2 \n")
}
test5.2.4 <- checkvars(test2.4)
if (!test5.2.4){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test5.2.4 failed: 'checkvars' fails on test2.4")
  FailedTestObjName <- c(FailedTestObjName, "test5.2.4")
  if (StopOnError) {
    stop("FCSgateclass: test5.2.4 failed: 'checkvars' fails on test2.4 \n")
  }
} else {
  cat("FCSgateclass: test5.2.4 succeeded: 'checkvars' succeeds on test2.4 \n")
}
test5.2.4.1 <- checkvars(test2.4.1)
if (!test5.2.4.1){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test5.2.4.1 failed: 'checkvars' fails on test2.4.1")
  FailedTestObjName <- c(FailedTestObjName, "test5.2.4.1")
  if (StopOnError) {
    stop("FCSgateclass: test5.2.4.1 failed: 'checkvars' fails on test2.4.1 \n")
  }
} else {
  cat("FCSgateclass: test5.2.4.1 succeeded: 'checkvars' succeeds on test2.4.1 \n")
}
test5.2.4.2 <- checkvars(test2.4.2)
if (!test5.2.4.2){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test5.2.4.2 failed: 'checkvars' fails on test2.4.2")
  FailedTestObjName <- c(FailedTestObjName, "test5.2.4.2")
  if (StopOnError) {
    stop("FCSgateclass: test5.2.4.2 failed: 'checkvars' fails on test2.4.2 \n")
  }
} else {
  cat("FCSgateclass: test5.2.4.2 succeeded: 'checkvars' succeeds on test2.4.2 \n")
}
test5.3 <- checkvars(test3)
if (!test5.3){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test5.3 failed: 'checkvars' fails on test3")
  FailedTestObjName <- c(FailedTestObjName, "test5.3")
  if (StopOnError) {
    stop("FCSgateclass: test5.3 failed: 'checkvars' fails on test3 \n")
  }
} else {
  cat("FCSgateclass: test5.3 succeeded: 'checkvars' succeeds on test3 \n")
}
test5.3.1 <- checkvars(test3.1)
if (!test5.3.1){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test5.3.1 failed: 'checkvars' fails on test3.1")
  FailedTestObjName <- c(FailedTestObjName, "test5.3.1")
  if (StopOnError) {
    stop("FCSgateclass: test5.3.1 failed: 'checkvars' fails on test3.1 \n")
  }
} else {
  cat("FCSgateclass: test5.3.1 succeeded: 'checkvars' succeeds on test3.1 \n")
}
test5.3.2 <- checkvars(test3.2)
if (!test5.3.2){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test5.3.2 failed: 'checkvars' fails on test3.2")
  FailedTestObjName <- c(FailedTestObjName, "test5.3.2")
  if (StopOnError) {
    stop("FCSgateclass: test5.3.2 failed: 'checkvars' fails on test3.2 \n")
  }
} else {
  cat("FCSgateclass: test5.3.2 succeeded: 'checkvars' succeeds on test3.2 \n")
}
test5.4 <- checkvars(test4)
if (!test5.4){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test5.4 failed: 'checkvars' fails on test4")
  FailedTestObjName <- c(FailedTestObjName, "test5.4")
  if (StopOnError) {
    stop("FCSgateclass: test5.4 failed: 'checkvars' fails on test4 \n")
  }
} else {
  cat("FCSgateclass: test5.4 succeeded: 'checkvars' succeeds on test4 \n")
}
test5.4.1 <- checkvars(test4.1)
if (!test5.4.1){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test5.4.1 failed: 'checkvars' fails on test4.1")
  FailedTestObjName <- c(FailedTestObjName, "test5.4.1")
  if (StopOnError) {
    stop("FCSgateclass: test5.4.1 failed: 'checkvars' fails on test4.1 \n")
  }
} else {
  cat("FCSgateclass: test5.4.1 succeeded: 'checkvars' succeeds on test4.1 \n")
}
test5.4.2 <- checkvars(test4.2)
if (!test5.4.2){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test5.4.2 failed: 'checkvars' fails on test4.2")
  FailedTestObjName <- c(FailedTestObjName, "test5.4.2")
  if (StopOnError) {
    stop("FCSgateclass: test5.4.2 failed: 'checkvars' fails on test4.2 \n")
  }
} else {
  cat("FCSgateclass: test5.4.2 succeeded: 'checkvars' succeeds on test4.2 \n")
}
## fixvars:: should be the same objects
test6.1 <- fixvars(test1)
if (!equals(test6.1, test1)){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test6.1 failed: 'fixvars' fails on test1")
  FailedTestObjName <- c(FailedTestObjName, "test6.1")
  if (StopOnError) {
    stop("FCSgateclass: test6.1 failed: 'fixvars' fails on test1 \n")
  }
} else {
  cat("FCSgateclass: test6.1 succeeded: 'fixvars' succeeds on test1 \n")
}
test6.1.1 <- fixvars(test1.1)
if (!equals(test6.1.1, test1.1)){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test6.1.1 failed: 'fixvars' fails on test1.1")
  FailedTestObjName <- c(FailedTestObjName, "test6.1.1")
  if (StopOnError) {
    stop("FCSgateclass: test6.1.1 failed: 'fixvars' fails on test1.1 \n")
  }
} else {
  cat("FCSgateclass: test6.1.1 succeeded: 'fixvars' succeeds on test1.1 \n")
}
test6.1.2 <- fixvars(test1.2)
if (!equals(test6.1.2, test1.2)){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test6.1.2 failed: 'fixvars' fails on test1.2")
  FailedTestObjName <- c(FailedTestObjName, "test6.1.2")
  if (StopOnError) {
    stop("FCSgateclass: test6.1.2 failed: 'fixvars' fails on test1.2 \n")
  }
} else {
  cat("FCSgateclass: test6.1.2 succeeded: 'fixvars' succeeds on test1.2 \n")
}
test6.2.1 <- fixvars(test2.1)
if (!equals(test6.2.1, test2.1)){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test6.2.1 failed: 'fixvars' fails on test2.1")
  FailedTestObjName <- c(FailedTestObjName, "test6.2.1")
  if (StopOnError) {
    stop("FCSgateclass: test6.2.1 failed: 'fixvars' fails on test2.1 \n")
  }
} else {
  cat("FCSgateclass: test6.2.1 succeeded: 'fixvars' succeeds on test2.1 \n")
}
test6.2.1.1 <- fixvars(test2.1.1)
if (!equals(test6.2.1.1, test2.1.1)){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test6.2.1.1 failed: 'fixvars' fails on test2.1.1")
  FailedTestObjName <- c(FailedTestObjName, "test6.2.1.1")
  if (StopOnError) {
    stop("FCSgateclass: test6.2.1.1 failed: 'fixvars' fails on test2.1.1 \n")
  }
} else {
  cat("FCSgateclass: test6.2.1.1 succeeded: 'fixvars' succeeds on test2.1.1 \n")
}
test6.2.1.2 <- fixvars(test2.1.2)
if (!equals(test6.2.1.2, test2.1.2)){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test6.2.1.2 failed: 'fixvars' fails on test2.1.2")
  FailedTestObjName <- c(FailedTestObjName, "test6.2.1.2")
  if (StopOnError) {
    stop("FCSgateclass: test6.2.1.2 failed: 'fixvars' fails on test2.1.2 \n")
  }
} else {
  cat("FCSgateclass: test6.2.1.2 succeeded: 'fixvars' succeeds on test2.1.2 \n")
}
test6.2.2 <- fixvars(test2.2)
if (!equals(test6.2.2, test2.2)){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test6.2.2 failed: 'fixvars' fails on test2.2")
  FailedTestObjName <- c(FailedTestObjName, "test6.2.2")
  if (StopOnError) {
    stop("FCSgateclass: test6.2.2 failed: 'fixvars' fails on test2.2 \n")
  }
} else {
  cat("FCSgateclass: test6.2.2 succeeded: 'fixvars' succeeds on test2.2 \n")
}
test6.2.2.1 <- fixvars(test2.2.1)
if (!equals(test6.2.2.1, test2.2.1)){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test6.2.2.1 failed: 'fixvars' fails on test2.2.1")
  FailedTestObjName <- c(FailedTestObjName, "test6.2.2.1")
  if (StopOnError) {
    stop("FCSgateclass: test6.2.2.1 failed: 'fixvars' fails on test2.2.1 \n")
  }
} else {
  cat("FCSgateclass: test6.2.2.1 succeeded: 'fixvars' succeeds on test2.2.1 \n")
}
test6.2.2.2 <- fixvars(test2.2.2)
if (!equals(test6.2.2.2, test2.2.2)){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test6.2.2.2 failed: 'fixvars' fails on test2.2.2")
  FailedTestObjName <- c(FailedTestObjName, "test6.2.2.2")
  if (StopOnError) {
    stop("FCSgateclass: test6.2.2.2 failed: 'fixvars' fails on test2.2.2 \n")
  }
} else {
  cat("FCSgateclass: test6.2.2.2 succeeded: 'fixvars' succeeds on test2.2.2 \n")
}
test6.2.3 <- fixvars(test2.3)
if (!equals(test6.2.3, test2.3)){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test6.2.3 failed: 'fixvars' fails on test2.3")
  FailedTestObjName <- c(FailedTestObjName, "test6.2.3")
  if (StopOnError) {
    stop("FCSgateclass: test6.2.3 failed: 'fixvars' fails on test2.3 \n")
  }
} else {
  cat("FCSgateclass: test6.2.3 succeeded: 'fixvars' succeeds on test2.3 \n")
}
test6.2.3.1 <- fixvars(test2.3.1)
if (!equals(test6.2.3.1, test2.3.1)){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test6.2.3.1 failed: 'fixvars' fails on test2.3.1")
  FailedTestObjName <- c(FailedTestObjName, "test6.2.3.1")
  if (StopOnError) {
    stop("FCSgateclass: test6.2.3.1 failed: 'fixvars' fails on test2.3.1 \n")
  }
} else {
  cat("FCSgateclass: test6.2.3.1 succeeded: 'fixvars' succeeds on test2.3.1 \n")
}
test6.2.3.2 <- fixvars(test2.3.2)
if (!equals(test6.2.3.2, test2.3.2)){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test6.2.3.2 failed: 'fixvars' fails on test2.3.2")
  FailedTestObjName <- c(FailedTestObjName, "test6.2.3.2")
  if (StopOnError) {
    stop("FCSgateclass: test6.2.3.2 failed: 'fixvars' fails on test2.3.2 \n")
  }
} else {
  cat("FCSgateclass: test6.2.3.2 succeeded: 'fixvars' succeeds on test2.3.2 \n")
}
test6.2.4 <- fixvars(test2.4)
if (!equals(test6.2.4, test2.4)){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test6.2.4 failed: 'fixvars' fails on test2.4")
  FailedTestObjName <- c(FailedTestObjName, "test6.2.4")
  if (StopOnError) {
    stop("FCSgateclass: test6.2.4 failed: 'fixvars' fails on test2.4 \n")
  }
} else {
  cat("FCSgateclass: test6.2.4 succeeded: 'fixvars' succeeds on test2.4 \n")
}
test6.2.4.1 <- fixvars(test2.4.1)
if (!equals(test6.2.4.1, test2.4.1)){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test6.2.4.1 failed: 'fixvars' fails on test2.4.1")
  FailedTestObjName <- c(FailedTestObjName, "test6.2.4.1")
  if (StopOnError) {
    stop("FCSgateclass: test6.2.4.1 failed: 'fixvars' fails on test2.4.1 \n")
  }
} else {
  cat("FCSgateclass: test6.2.4.1 succeeded: 'fixvars' succeeds on test2.4.1 \n")
}
test6.2.4.2 <- fixvars(test2.4.2)
if (!equals(test6.2.4.2, test2.4.2)){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test6.2.4.2 failed: 'fixvars' fails on test2.4.2")
  FailedTestObjName <- c(FailedTestObjName, "test6.2.4.2")
  if (StopOnError) {
    stop("FCSgateclass: test6.2.4.2 failed: 'fixvars' fails on test2.4.2 \n")
  }
} else {
  cat("FCSgateclass: test6.2.4.2 succeeded: 'fixvars' succeeds on test2.4.2 \n")
}
test6.3 <- fixvars(test3)
if (!equals(test6.3, test3)){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test6.3 failed: 'fixvars' fails on test3")
  FailedTestObjName <- c(FailedTestObjName, "test6.3")
  if (StopOnError) {
    stop("FCSgateclass: test6.3 failed: 'fixvars' fails on test3 \n")
  }
} else {
  cat("FCSgateclass: test6.3 succeeded: 'fixvars' succeeds on test3 \n")
}
test6.3.1 <- fixvars(test3.1)
if (!equals(test6.3.1, test3.1)){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test6.3.1 failed: 'fixvars' fails on test3.1")
  FailedTestObjName <- c(FailedTestObjName, "test6.3.1")
  if (StopOnError) {
    stop("FCSgateclass: test6.3.1 failed: 'fixvars' fails on test3.1 \n")
  }
} else {
  cat("FCSgateclass: test6.3.1 succeeded: 'fixvars' succeeds on test3.1 \n")
}
test6.3.2 <- fixvars(test3.2)
if (!equals(test6.3.2, test3.2)){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test6.3.2 failed: 'fixvars' fails on test3.2")
  FailedTestObjName <- c(FailedTestObjName, "test6.3.2")
  if (StopOnError) {
    stop("FCSgateclass: test6.3.2 failed: 'fixvars' fails on test3.2 \n")
  }
} else {
  cat("FCSgateclass: test6.3.2 succeeded: 'fixvars' succeeds on test3.2 \n")
}
test6.4 <- fixvars(test4)
if (!equals(test6.4, test4)){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test6.4 failed: 'fixvars' fails on test4")
  FailedTestObjName <- c(FailedTestObjName, "test6.4")
  if (StopOnError) {
    stop("FCSgateclass: test6.4 failed: 'fixvars' fails on test4 \n")
  }
} else {
  cat("FCSgateclass: test6.4 succeeded: 'fixvars' succeeds on test4 \n")
}
test6.4.1 <- fixvars(test4.1)
if (!equals(test6.4.1, test4.1)){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test6.4.1 failed: 'fixvars' fails on test4.1")
  FailedTestObjName <- c(FailedTestObjName, "test6.4.1")
  if (StopOnError) {
    stop("FCSgateclass: test6.4.1 failed: 'fixvars' fails on test4.1 \n")
  }
} else {
  cat("FCSgateclass: test6.4.1 succeeded: 'fixvars' succeeds on test4.1 \n")
}
test6.4.2 <- fixvars(test4.2)
if (!equals(test6.4.2, test4.2)){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test6.4.2 failed: 'fixvars' fails on test4.2")
  FailedTestObjName <- c(FailedTestObjName, "test6.4.2")
  if (StopOnError) {
    stop("FCSgateclass: test6.4.2 failed: 'fixvars' fails on test4.2 \n")
  }
} else {
  cat("FCSgateclass: test6.4.2 succeeded: 'fixvars' succeeds on test4.2 \n")
}
### try igate.FCS, HTVN gating

## try out a gating sequence, prev.gateNum usage

## createGate on a extracted gated data & extract & extract

####  SOMETHING WRONG WITH THIS TEST!!  LOOK AT WHAT THE ISSUE IS
## REALLY HAVE NO DATA?
test7 <- createGate(test4.2, varpos=3, gatingrange=600,
                    type="uniscut", prev.gateNum=2, prev.IndexValue.In=0,
                    comment="extracted test4.2", MY.DEBUG=TRUE)

test7.2 <- extractGatedData(test7, gateNum=3,
                            IndexValue.In=1,
                            MY.DEBUG=TRUE)


## what is a good way to test?
min.test7.2v3 <- apply(as(test7.2@data, "matrix"), 2, min)[3]
max.test7.2v3 <- apply(as(test7.2@data, "matrix"), 2, max)[3]

min.test7.2v1 <- apply(as(test7.2@data, "matrix"), 2, min)[2]
max.test7.2v1 <- apply(as(test7.2@data, "matrix"), 2, max)[2]

min.test7.2v2 <- apply(as(test7.2@data, "matrix"), 2, min)[4]
max.test7.2v2 <- apply(as(test7.2@data, "matrix"), 2, max)[4]

if (((min.test7.2v1 >= 256) & (min.test7.2v2 >=100) & (max.test7.2v1 <= 900) & (max.test7.2v2 <= 400) & (min.test7.2v3 >=600) & (max.test7.2v3 <=1024))){
  ErrorMsg <- c(ErrorMsg, "FCSgateclass: test7.2 failed: Can't get gate on already gated object")
  FailedTestObjName <- c(FailedTestObjName, "test7.2")
  if (StopOnError) {
    stop("FCSgateclass: test7.2 failed: Can't get gate on already gated object \n")
  }
} else {
  cat("FCSgateclass: test7.2 succeeded: Able to get gate on already gated object \n")
}
## createGate after createGate and then extract


if (is.null(FailedTestObjName) & is.null(ErrorMsg)){
  names.failed <- "None; all FCSmetadataclass tests were successful."
  error.printed <- "None; all FCSmetadataclass tests were successful."
} else {
  names.failed <- matrix(FailedTestObjName, ncol=1)
  error.printed <- ErrorMsg
}
cat("These are the following test objects that have failed: \n\n")
print(names.failed)
cat("\n\n\n")
cat("These are the corresponding Error Messages: \n\n")
print(error.printed)
