## StopOnError or else continue through

if ("StopOnError" %in% objects()){
  if (!is.logical(StopOnError)) {
    ## default is TRUE when StopOnError is not boolean
    StopOnError <- TRUE
  }    
} else {
  ## default is to stop when there is an error 
  StopOnError <- TRUE
}



if (!require(rflowcyt)){
  library(rflowcyt, lib.loc="~/lib/R")
}


ErrorMsg <- NULL
FailedTestObjName <- NULL
error.printed <- names.failed <- NULL

##  testing rflowcytests function
## first scenario : 2 univariate samples from the same distributions
##    all tests should be insignificant
set.seed(20)
samp1 <- round(rnorm(1000, mean=500, sd=100), 0)
samp2 <- round(rnorm(1000, mean =500, sd=100), 0)

pval.out1 <- runflowcytests(samp2, samp1)["pvalues"]
test1.same <- sum((pval.out1[!is.na(pval.out1)])<= 0.05) == 0
if (!test1.same) {
  ErrorMsg <- c(ErrorMsg, "test1.same failed: runflowcytests can NOT test for non-significant results")
  FailedTestObjName <- c(FailedTestObjName, "test1.same")
  if (StopOnError){
    stop("test1.same failed: runflowcytests can NOT test for non-significant results\n")
  }
} else {
  cat("test1.same succeeded: runflowcytests can test for non-significant results\n")
}
## second scenario : 2 univariate samples from different distributions
##    all tests should be significant
samp1 <- round(rnorm(1000, mean=500, sd=100), 0)
samp2 <- round(rchisq(1000, 2, 500), 0)

pval.out2 <- runflowcytests(samp2, samp1)["pvalues"]
test2.diff <- sum((pval.out2[!is.na(pval.out2)])> 0.05) == 0
if (!test2.diff) {
  ErrorMsg <- c(ErrorMsg, "test2.diff failed: runflowcytests can NOT test for significant results")
  FailedTestObjName <- c(FailedTestObjName, "test2.diff")
  if (StopOnError){
    stop("test2.diff failed: runflowcytests can NOT test for significant results\n")
  }
} else {
  cat("test2.diff succeeded: runflowcytests can test for significant results\n")
}
